=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2011-06-14 22:09:19 +0000
+++ client/drizzletest.cc	2011-06-16 18:54:30 +0000
@@ -230,14 +230,31 @@
 typedef boost::unordered_map<string, VAR *> var_hash_t;
 var_hash_t var_hash;
 
-struct st_connection
+class st_connection
 {
-  drizzle_st* drizzle;
-  drizzle_con_st con;
-  char* name;
+public:
+  st_connection() : con(drizzle)
+  {
+    drizzle_con_add_options(*this, use_drizzle_protocol ? DRIZZLE_CON_EXPERIMENTAL : DRIZZLE_CON_MYSQL);
+  }
+
+  operator drizzle::connection_c&()
+  {
+    return con;
+  }
+
+  operator drizzle_con_st*()
+  {
+    return &con.b_;
+  }
+
+  drizzle::drizzle_c drizzle;
+  drizzle::connection_c con;
 };
-st_connection g_connections[128];
-st_connection* cur_con= NULL, *next_con;
+
+typedef map<string, st_connection*> connections_t;
+connections_t g_connections;
+st_connection* cur_con= NULL;
 
 /*
   List of commands in drizzletest
@@ -465,7 +482,7 @@
 /* For replace_column */
 static char *replace_column[MAX_COLUMNS];
 static uint32_t max_replace_column= 0;
-void do_get_replace_column(struct st_command*);
+void do_get_replace_column(st_command*);
 void free_replace_column();
 
 /* For replace */
@@ -475,16 +492,15 @@
 /* For replace_regex */
 void do_get_replace_regex(st_command* command);
 
-void replace_append_mem(string *ds, const char *val,
-                        int len);
+void replace_append_mem(string& ds, const char *val, int len);
 void replace_append(string *ds, const char *val);
 void replace_append_uint(string *ds, uint32_t val);
-void append_sorted(string* ds, string* ds_input);
+void append_sorted(string& ds, const string& ds_input);
 
-void handle_error(struct st_command*,
+void handle_error(st_command*,
                   unsigned int err_errno, const char *err_error,
                   const char *err_sqlstate, string *ds);
-void handle_no_error(struct st_command*);
+void handle_no_error(st_command*);
 
 
 void do_eval(string *query_eval, const char *query,
@@ -492,11 +508,11 @@
 {
   char c, next_c;
   int escaped = 0;
-  VAR *v;
 
   for (const char *p= query; (c= *p) && p < query_end; ++p)
   {
-    switch(c) {
+    switch(c) 
+    {
     case '$':
       if (escaped)
       {
@@ -505,7 +521,8 @@
       }
       else
       {
-        if (!(v= var_get(p, &p, 0, 0)))
+        VAR* v= var_get(p, &p, 0, 0);
+        if (not v)
           die("Bad variable in eval");
         query_eval->append(v->str_val, v->str_val_len);
       }
@@ -534,10 +551,8 @@
     default:
       escaped= 0;
       query_eval->append(p, 1);
-      break;
     }
   }
-  return;
 }
 
 
@@ -570,7 +585,7 @@
     const char *next_pos= cur_pos;
 
     /* Search for quote in each string and replace with escaped quote */
-    while((next_pos= strrchr(cur_pos, quote_str[0])) != NULL)
+    while ((next_pos= strrchr(cur_pos, quote_str[0])) != NULL)
     {
       str->append(cur_pos, next_pos - cur_pos);
       str->append("\\", 1);
@@ -598,68 +613,49 @@
 
 */
 
-static void show_query(drizzle_con_st *con, const char* query)
+static int dt_query_log(drizzle::connection_c& con, drizzle::result_c& res, const std::string& query)
 {
-  drizzle_result_st res;
-  drizzle_return_t ret;
-
-  if (!con)
-    return;
-
-  if (drizzle_query_str(con, &res, query, &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
+  if (drizzle_return_t ret= con.query(res, query))
   {
     if (ret == DRIZZLE_RETURN_ERROR_CODE)
     {
-      log_msg("Error running query '%s': %d %s",
-              query, drizzle_result_error_code(&res),
-              drizzle_result_error(&res));
-      drizzle_result_free(&res);
+      log_msg("Error running query '%s': %d %s", query.c_str(), res.error_code(), res.error());
     }
     else
     {
-      log_msg("Error running query '%s': %d %s",
-              query, ret, drizzle_con_error(con));
+      log_msg("Error running query '%s': %d %s", query.c_str(), ret, con.error());
     }
-    return;
-  }
-
-  if (drizzle_result_column_count(&res) == 0 ||
-      drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-  {
-    /* No result set returned */
-    drizzle_result_free(&res);
-    return;
-  }
-
-  {
-    drizzle_row_t row;
-    unsigned int i;
-    unsigned int row_num= 0;
-    unsigned int num_fields= drizzle_result_column_count(&res);
-    drizzle_column_st *column;
-
-    fprintf(stderr, "=== %s ===\n", query);
-    while ((row= drizzle_row_next(&res)))
+    return 1;
+  }
+  return res.column_count() == 0;
+}
+
+static void show_query(drizzle::connection_c& con, const char* query)
+{
+  drizzle::result_c res;
+  if (dt_query_log(con, res, query))
+    return;
+
+  unsigned int row_num= 0;
+  unsigned int num_fields= res.column_count();
+
+  fprintf(stderr, "=== %s ===\n", query);
+  while (drizzle_row_t row= res.row_next())
+  {
+    size_t *lengths= res.row_field_sizes();
+    row_num++;
+
+    fprintf(stderr, "---- %d. ----\n", row_num);
+    res.column_seek(0);
+    for (unsigned int i= 0; i < num_fields; i++)
     {
-      size_t *lengths= drizzle_row_field_sizes(&res);
-      row_num++;
-
-      fprintf(stderr, "---- %d. ----\n", row_num);
-      drizzle_column_seek(&res, 0);
-      for(i= 0; i < num_fields; i++)
-      {
-        column= drizzle_column_next(&res);
-        fprintf(stderr, "%s\t%.*s\n",
-                drizzle_column_name(column),
-                (int)lengths[i], row[i] ? row[i] : "NULL");
-      }
+      drizzle_column_st* column= res.column_next();
+      fprintf(stderr, "%s\t%.*s\n", drizzle_column_name(column), (int)lengths[i], row[i] ? row[i] : "NULL");
     }
-    for (i= 0; i < strlen(query)+8; i++)
-      fprintf(stderr, "=");
-    fprintf(stderr, "\n\n");
   }
-  drizzle_result_free(&res);
+  for (size_t i= 0; i < strlen(query)+8; i++)
+    fprintf(stderr, "=");
+  fprintf(stderr, "\n\n");
 }
 
 
@@ -676,84 +672,45 @@
 
 */
 
-static void show_warnings_before_error(drizzle_con_st *con)
+static void show_warnings_before_error(drizzle::connection_c& con)
 {
-  drizzle_result_st res;
-  drizzle_return_t ret;
-  const char* query= "SHOW WARNINGS";
-
-  if (!con)
-    return;
-
-  if (drizzle_query_str(con, &res, query, &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
-  {
-    if (ret == DRIZZLE_RETURN_ERROR_CODE)
-    {
-      log_msg("Error running query '%s': %d %s",
-              query, drizzle_result_error_code(&res),
-              drizzle_result_error(&res));
-      drizzle_result_free(&res);
-    }
-    else
-    {
-      log_msg("Error running query '%s': %d %s",
-              query, ret, drizzle_con_error(con));
-    }
-    return;
-  }
-
-  if (drizzle_result_column_count(&res) == 0 ||
-      drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-  {
-    /* No result set returned */
-    drizzle_result_free(&res);
-    return;
-  }
-
-  if (drizzle_result_row_count(&res) <= 1)
-  {
-    /* Don't display the last row, it's "last error" */
-  }
-  else
-  {
-    drizzle_row_t row;
+  drizzle::result_c res;
+  if (dt_query_log(con, res, "show warnings"))
+    return;
+
+  if (res.row_count() >= 2) /* Don't display the last row, it's "last error" */
+  {
     unsigned int row_num= 0;
-    unsigned int num_fields= drizzle_result_column_count(&res);
+    unsigned int num_fields= res.column_count();
 
     fprintf(stderr, "\nWarnings from just before the error:\n");
-    while ((row= drizzle_row_next(&res)))
+    while (drizzle_row_t row= res.row_next())
     {
-      uint32_t i;
-      size_t *lengths= drizzle_row_field_sizes(&res);
+      size_t *lengths= res.row_field_sizes();
 
-      if (++row_num >= drizzle_result_row_count(&res))
+      if (++row_num >= res.row_count())
       {
         /* Don't display the last row, it's "last error" */
         break;
       }
 
-      for(i= 0; i < num_fields; i++)
+      for (uint32_t i= 0; i < num_fields; i++)
       {
-        fprintf(stderr, "%.*s ", (int)lengths[i],
-                row[i] ? row[i] : "NULL");
+        fprintf(stderr, "%.*s ", (int)lengths[i], row[i] ? row[i] : "NULL");
       }
       fprintf(stderr, "\n");
     }
   }
-  drizzle_result_free(&res);
-
-  return;
 }
 
-
 enum arg_type
 {
   ARG_STRING,
   ARG_REST
 };
 
-struct command_arg {
+struct command_arg 
+{
   const char *argname;       /* Name of argument   */
   enum arg_type type;        /* Type of argument   */
   bool required;          /* Argument required  */
@@ -767,11 +724,10 @@
                                const struct command_arg *args,
                                int num_args, const char delimiter_arg)
 {
-  int i;
   const char *ptr= arguments;
   const char *start;
 
-  for (i= 0; i < num_args; i++)
+  for (int i= 0; i < num_args; i++)
   {
     const struct command_arg *arg= &args[i];
     arg->ds->clear();
@@ -824,7 +780,7 @@
   }
   /* Check for too many arguments passed */
   ptr= command->last_argument;
-  while(ptr <= command->end)
+  while (ptr <= command->end)
   {
     if (*ptr && *ptr != ' ')
       die("Extra argument '%s' passed to '%.*s'",
@@ -839,15 +795,12 @@
 {
   if (error != 0)
   {
-    uint32_t i;
-
     if (command->abort_on_error)
-      die("command \"%.*s\" failed with error %d",
-          command->first_word_len, command->query, error);
-    for (i= 0; i < command->expected_errors.count; i++)
+      die("command \"%.*s\" failed with error %d", command->first_word_len, command->query, error);
+    for (uint32_t i= 0; i < command->expected_errors.count; i++)
     {
-      if ((command->expected_errors.err[i].type == ERR_ERRNO) &&
-          (command->expected_errors.err[i].code.errnum == error))
+      if (command->expected_errors.err[i].type == ERR_ERRNO &&
+          command->expected_errors.err[i].code.errnum == error)
       {
         return;
       }
@@ -866,20 +819,6 @@
 }
 
 
-static void close_connections()
-{
-  for (--next_con; next_con >= g_connections; --next_con)
-  {
-    if (next_con->drizzle != NULL)
-    {
-      drizzle_free(next_con->drizzle);
-      next_con->drizzle= NULL;
-    }
-    free(next_con->name);
-  }
-}
-
-
 static void close_files()
 {
   for (; cur_file >= file_stack.data(); cur_file--)
@@ -893,7 +832,6 @@
 
 static void free_used_memory()
 {
-  close_connections();
   close_files();
   BOOST_FOREACH(var_hash_t::reference i, var_hash)
   {
@@ -946,27 +884,25 @@
 
 void die(const char *fmt, ...)
 {
-  static int dying= 0;
-  va_list args;
-
   /*
     Protect against dying twice
     first time 'die' is called, try to write log files
     second time, just exit
   */
+  static bool dying= false;
   if (dying)
     cleanup_and_exit(1);
-  dying= 1;
+  dying= true;
 
   /* Print the error message */
   fprintf(stderr, "drizzletest: ");
   if (cur_file && cur_file != file_stack.data())
-    fprintf(stderr, "In included file \"%s\": ",
-            cur_file->file_name);
+    fprintf(stderr, "In included file \"%s\": ", cur_file->file_name);
   if (start_lineno > 0)
     fprintf(stderr, "At line %u: ", start_lineno);
   if (fmt)
   {
+    va_list args;
     va_start(args, fmt);
     vfprintf(stderr, fmt, args);
     va_end(args);
@@ -981,7 +917,7 @@
   {
     int tail_lines= opt_tail_lines;
     const char* show_from= ds_res.c_str() + ds_res.length() - 1;
-    while(show_from > ds_res.c_str() && tail_lines > 0 )
+    while (show_from > ds_res.c_str() && tail_lines > 0 )
     {
       show_from--;
       if (*show_from == '\n')
@@ -1007,7 +943,7 @@
     been produced prior to the error
   */
   if (cur_con)
-    show_warnings_before_error(&cur_con->con);
+    show_warnings_before_error(*cur_con);
 
   cleanup_and_exit(1);
 }
@@ -1016,7 +952,7 @@
 void abort_not_supported_test(const char *fmt, ...)
 {
   va_list args;
-  struct st_test_file* err_file= cur_file;
+  st_test_file* err_file= cur_file;
 
 
   /* Print include filestack */
@@ -1048,16 +984,13 @@
 
 void verbose_msg(const char *fmt, ...)
 {
-  va_list args;
-
   if (!verbose)
     return;
-
+  va_list args;
   va_start(args, fmt);
   fprintf(stderr, "drizzletest: ");
   if (cur_file && cur_file != file_stack.data())
-    fprintf(stderr, "In included file \"%s\": ",
-            cur_file->file_name);
+    fprintf(stderr, "In included file \"%s\": ", cur_file->file_name);
   if (start_lineno != 0)
     fprintf(stderr, "At line %u: ", start_lineno);
   vfprintf(stderr, fmt, args);
@@ -1072,7 +1005,6 @@
   char buff[512];
   size_t len;
 
-
   va_start(args, fmt);
   ds_warning_messages.append("drizzletest: ");
   if (start_lineno != 0)
@@ -1123,15 +1055,13 @@
 
 */
 
-static void cat_file(string* ds, const char* filename)
+static void cat_file(string& ds, const char* filename)
 {
   int fd= internal::my_open(filename, O_RDONLY, MYF(0));
   if (fd < 0)
     die("Failed to open file '%s'", filename);
-  uint32_t len;
   char buff[512];
-
-  while((len= internal::my_read(fd, (unsigned char*)&buff, sizeof(buff), MYF(0))) > 0)
+  while (uint32_t len= internal::my_read(fd, (unsigned char*)&buff, sizeof(buff), MYF(0)))
   {
     char *p= buff, *start= buff;
     while (p < buff+len)
@@ -1142,7 +1072,7 @@
         /* Add fake newline instead of cr and output the line */
         *p= '\n';
         p++; /* Step past the "fake" newline */
-        ds->append(start, p-start);
+        ds.append(start, p - start);
         p++; /* Step past the "fake" newline */
         start= p;
       }
@@ -1150,7 +1080,7 @@
         p++;
     }
     /* Output any chars that might be left */
-    ds->append(start, p-start);
+    ds.append(start, p - start);
   }
   internal::my_close(fd, MYF(0));
 }
@@ -1232,10 +1162,8 @@
 
 */
 
-static void show_diff(string* ds,
-                      const char* filename1, const char* filename2)
+static void show_diff(string* ds, const char* filename1, const char* filename2)
 {
-
   string ds_tmp;
 
   /* First try with unified diff */
@@ -1274,11 +1202,11 @@
       ds_tmp.append(" --- ");
       ds_tmp.append(filename1);
       ds_tmp.append(" >>>\n");
-      cat_file(&ds_tmp, filename1);
+      cat_file(ds_tmp, filename1);
       ds_tmp.append("<<<\n --- ");
       ds_tmp.append(filename1);
       ds_tmp.append(" >>>\n");
-      cat_file(&ds_tmp, filename2);
+      cat_file(ds_tmp, filename2);
       ds_tmp.append("<<<<\n");
     }
   }
@@ -1344,7 +1272,7 @@
       die("Failed to open second file: '%s'", fname);
     }
   }
-  while((len= internal::my_read(fd, (unsigned char*)&buff,
+  while ((len= internal::my_read(fd, (unsigned char*)&buff,
                       sizeof(buff), MYF(0))) > 0)
   {
     if ((len2= internal::my_read(fd2, (unsigned char*)&buff2,
@@ -1416,7 +1344,7 @@
   See 'compare_files2'
 */
 
-static int string_cmp(string* ds, const char *fname)
+static int string_cmp(const string& ds, const char *fname)
 {
   char temp_file_path[FN_REFLEN];
 
@@ -1425,7 +1353,7 @@
     die("Failed to create temporary file for ds");
 
   /* Write ds to temporary file and set file pos to beginning*/
-  if (internal::my_write(fd, (unsigned char *) ds->c_str(), ds->length(), MYF(MY_FNABP | MY_WME)) ||
+  if (internal::my_write(fd, (unsigned char *) ds.data(), ds.length(), MYF(MY_FNABP | MY_WME)) ||
       lseek(fd, 0, SEEK_SET) == MY_FILEPOS_ERROR)
   {
     internal::my_close(fd, MYF(0));
@@ -1456,7 +1384,7 @@
 
 */
 
-static void check_result(string* ds)
+static void check_result(string& ds)
 {
   const char* mess= "Result content mismatch\n";
 
@@ -1490,9 +1418,9 @@
       /* Put reject file in opt_logdir */
       internal::fn_format(reject_file, result_file_name.c_str(), opt_logdir.c_str(), ".reject", MY_REPLACE_DIR | MY_REPLACE_EXT);
     }
-    str_to_file(reject_file, ds->c_str(), ds->length());
+    str_to_file(reject_file, ds.data(), ds.length());
 
-    ds->erase(); /* Don't create a .log file */
+    ds.erase(); /* Don't create a .log file */
 
     show_diff(NULL, result_file_name.c_str(), reject_file);
     die("%s",mess);
@@ -1519,7 +1447,7 @@
 
 */
 
-static void check_require(string* ds, const string &fname)
+static void check_require(const string& ds, const string& fname)
 {
   if (string_cmp(ds, fname.c_str()))
   {
@@ -1540,7 +1468,7 @@
   char* ptr= str;
 
   /* Check if the first non space character is c1 */
-  while(*ptr && my_isspace(charset_info, *ptr))
+  while (*ptr && my_isspace(charset_info, *ptr))
     ptr++;
   if (*ptr == c1)
   {
@@ -1549,7 +1477,7 @@
 
     /* Last non space charecter should be c2 */
     ptr= strchr(str, '\0')-1;
-    while(*ptr && my_isspace(charset_info, *ptr))
+    while (*ptr && my_isspace(charset_info, *ptr))
       ptr--;
     if (*ptr == c2)
     {
@@ -1785,16 +1713,27 @@
 
 */
 
+static void dt_query(drizzle::connection_c& con, drizzle::result_c& res, const std::string& query)
+{
+  if (drizzle_return_t ret= con.query(res, query))
+  {
+    if (ret == DRIZZLE_RETURN_ERROR_CODE)
+    {
+      die("Error running query '%s': %d %s", query.c_str(), res.error_code(), res.error());
+    }
+    else
+    {
+      die("Error running query '%s': %d %s", query.c_str(), ret, con.error());
+    }
+  }
+  if (res.column_count() == 0)
+    die("Query '%s' didn't return a result set", query.c_str());
+}
+
 static void var_query_set(VAR *var, const char *query, const char** query_end)
 {
-  const char *end = (char*)((query_end && *query_end) ?
-                            *query_end : query + strlen(query));
-  drizzle_result_st res;
-  drizzle_return_t ret;
-  drizzle_row_t row;
-  drizzle_con_st *con= &cur_con->con;
-  string ds_query;
-
+  const char *end = ((query_end && *query_end) ? *query_end : query + strlen(query));
+  drizzle::connection_c& con= *cur_con;
 
   while (end > query && *end != '`')
     --end;
@@ -1802,54 +1741,36 @@
     die("Syntax error in query, missing '`'");
   ++query;
 
+  string ds_query;
   /* Eval the query, thus replacing all environment variables */
   do_eval(&ds_query, query, end, false);
 
-  if (drizzle_query(con, &res, ds_query.c_str(), ds_query.length(),
-                    &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
-  {
-    if (ret == DRIZZLE_RETURN_ERROR_CODE)
-    {
-      die("Error running query '%s': %d %s", ds_query.c_str(),
-          drizzle_result_error_code(&res), drizzle_result_error(&res));
-      drizzle_result_free(&res);
-    }
-    else
-    {
-      die("Error running query '%s': %d %s", ds_query.c_str(), ret,
-          drizzle_con_error(con));
-    }
-  }
-  if (drizzle_result_column_count(&res) == 0 ||
-      drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-    die("Query '%s' didn't return a result set", ds_query.c_str());
+  drizzle::result_c res;
+  dt_query(con, res, ds_query);
 
-  if ((row= drizzle_row_next(&res)) && row[0])
+  drizzle_row_t row= res.row_next();
+  if (row && row[0])
   {
     /*
       Concatenate all fields in the first row with tab in between
       and assign that string to the $variable
     */
     string result;
-    size_t* lengths= drizzle_row_field_sizes(&res);
-    for (uint32_t i= 0; i < drizzle_result_column_count(&res); i++)
+    size_t* lengths= res.row_field_sizes();
+    for (uint32_t i= 0; i < res.column_count(); i++)
     {
       if (row[i])
       {
         /* Add column to tab separated string */
         result.append(row[i], lengths[i]);
       }
-      result.append("\t", 1);
+      result += "\t";
     }
-    end= result.c_str() + result.length()-1;
+    end= result.c_str() + result.length() - 1;
     eval_expr(var, result.c_str(), (const char**) &end);
   }
   else
     eval_expr(var, "", 0);
-
-  drizzle_result_free(&res);
-  return;
 }
 
 
@@ -1878,9 +1799,7 @@
 static void var_set_query_get_value(st_command* command, VAR *var)
 {
   int col_no= -1;
-  drizzle_result_st res;
-  drizzle_return_t ret;
-  drizzle_con_st *con= &cur_con->con;
+  drizzle::connection_c& con= *cur_con;
 
   string ds_query;
   string ds_col;
@@ -1912,30 +1831,15 @@
     die("Mismatched \"'s around query '%s'", ds_query.c_str());
   ds_query= unstripped_query;
 
-  /* Run the query */
-  if (drizzle_query(con, &res, ds_query.c_str(), ds_query.length(), &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
-  {
-    if (ret == DRIZZLE_RETURN_ERROR_CODE)
-    {
-      die("Error running query '%s': %d %s", ds_query.c_str(), drizzle_result_error_code(&res), drizzle_result_error(&res));
-      drizzle_result_free(&res);
-    }
-    else
-    {
-      die("Error running query '%s': %d %s", ds_query.c_str(), ret, drizzle_con_error(con));
-    }
-  }
-  if (drizzle_result_column_count(&res) == 0 ||
-      drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-    die("Query '%s' didn't return a result set", ds_query.c_str());
+  drizzle::result_c res;
+  dt_query(con, res, ds_query);
 
   {
     /* Find column number from the given column name */
-    uint32_t num_fields= drizzle_result_column_count(&res);
+    uint32_t num_fields= res.column_count();
     for (uint32_t i= 0; i < num_fields; i++)
     {
-      drizzle_column_st* column= drizzle_column_next(&res);
+      drizzle_column_st* column= res.column_next();
       if (strcmp(drizzle_column_name(column), ds_col.c_str()) == 0 &&
           strlen(drizzle_column_name(column)) == ds_col.length())
       {
@@ -1945,9 +1849,7 @@
     }
     if (col_no == -1)
     {
-      drizzle_result_free(&res);
-      die("Could not find column '%s' in the result of '%s'",
-          ds_col.c_str(), ds_query.c_str());
+      die("Could not find column '%s' in the result of '%s'", ds_col.c_str(), ds_query.c_str());
     }
   }
 
@@ -1956,23 +1858,17 @@
     long rows= 0;
     const char* value= "No such row";
 
-    while (drizzle_row_t row= drizzle_row_next(&res))
+    while (drizzle_row_t row= res.row_next())
     {
       if (++rows == row_no)
       {
-
         /* Found the row to get */
-        if (row[col_no])
-          value= row[col_no];
-        else
-          value= "NULL";
-
+        value= row[col_no] ? row[col_no] : "NULL";
         break;
       }
     }
     eval_expr(var, value, 0);
   }
-  drizzle_result_free(&res);
 }
 
 
@@ -2229,8 +2125,7 @@
 
     if (command->abort_on_error)
     {
-      log_msg("exec of '%s' failed, error: %d, status: %d, errno: %d",
-              ds_cmd.c_str(), error, status, errno);
+      log_msg("exec of '%s' failed, error: %d, status: %d, errno: %d", ds_cmd.c_str(), error, status, errno);
       die("command \"%s\" failed", command->first_argument);
     }
 
@@ -2252,8 +2147,7 @@
            command->expected_errors.err[0].code.errnum != 0)
   {
     /* Error code we wanted was != 0, i.e. not an expected success */
-    log_msg("exec of '%s failed, error: %d, errno: %d",
-            ds_cmd.c_str(), error, errno);
+    log_msg("exec of '%s failed, error: %d, errno: %d", ds_cmd.c_str(), error, errno);
     die("command \"%s\" succeeded - should have failed with errno %d...",
         command->first_argument, command->expected_errors.err[0].code.errnum);
   }
@@ -2714,7 +2608,7 @@
                      sizeof(cat_file_args)/sizeof(struct command_arg),
                      ' ');
 
-  cat_file(&ds_res, ds_filename.c_str());
+  cat_file(ds_res, ds_filename.c_str());
 }
 
 
@@ -2758,18 +2652,6 @@
   handle_command_error(command, error);
 }
 
-
-static st_connection * find_connection_by_name(const char *name)
-{
-  for (st_connection* con= g_connections; con < next_con; con++)
-  {
-    if (not strcmp(con->name, name))
-      return con;
-  }
-  return NULL;
-}
-
-
 /*
   SYNOPSIS
   do_send_quit
@@ -2782,26 +2664,25 @@
 
 static void do_send_quit(st_command* command)
 {
-  char *p= command->first_argument, *name;
-  st_connection *con;
-  drizzle_result_st result;
-  drizzle_return_t ret;
+  char* p= command->first_argument;
 
-  if (!*p)
+  if (not *p)
     die("Missing connection name in send_quit");
-  name= p;
-  while (*p && !my_isspace(charset_info,*p))
+  char* name= p;
+  while (*p && !my_isspace(charset_info, *p))
     p++;
 
   if (*p)
     *p++= 0;
   command->last_argument= p;
 
-  if (!(con= find_connection_by_name(name)))
+  st_connection* con= find_ptr2(g_connections, name);
+  if (not con)
     die("connection '%s' not found in connection pool", name);
 
-  if (drizzle_quit(&con->con,&result, &ret))
-    drizzle_result_free(&result);
+  drizzle::result_c result;
+  drizzle_return_t ret;
+  drizzle_quit(*con, &result.b_, &ret);
 }
 
 
@@ -2821,7 +2702,7 @@
 
 */
 
-static void do_change_user(struct st_command *)
+static void do_change_user(st_command *)
 {
   assert(0);
 }
@@ -2847,14 +2728,11 @@
 
 static void do_perl(st_command* command)
 {
-  int error;
-  int fd;
-  FILE *res_file;
   char buf[FN_REFLEN];
   char temp_file_path[FN_REFLEN];
   string ds_script;
   string ds_delimiter;
-  const struct command_arg perl_args[] = {
+  const command_arg perl_args[] = {
     { "delimiter", ARG_STRING, false, &ds_delimiter, "Delimiter to read until" }
   };
 
@@ -2872,8 +2750,8 @@
   read_until_delimiter(&ds_script, &ds_delimiter);
 
   /* Create temporary file name */
-  if ((fd= internal::create_temp_file(temp_file_path, getenv("MYSQLTEST_VARDIR"),
-                            "tmp", MYF(MY_WME))) < 0)
+  int fd= internal::create_temp_file(temp_file_path, getenv("MYSQLTEST_VARDIR"), "tmp", MYF(MY_WME));
+  if (fd < 0)
     die("Failed to create temporary file for perl command");
   internal::my_close(fd, MYF(0));
 
@@ -2882,7 +2760,8 @@
   /* Format the "perl <filename>" command */
   snprintf(buf, sizeof(buf), "perl %s", temp_file_path);
 
-  if (!(res_file= popen(buf, "r")) && command->abort_on_error)
+  FILE* res_file= popen(buf, "r");
+  if (not res_file && command->abort_on_error)
     die("popen(\"%s\", \"r\") failed", buf);
 
   while (fgets(buf, sizeof(buf), res_file))
@@ -2892,7 +2771,7 @@
     else
       replace_append(&ds_res, buf);
   }
-  error= pclose(res_file);
+  int error= pclose(res_file);
 
   /* Remove the temporary file */
   internal::my_delete(temp_file_path, MYF(0));
@@ -2928,57 +2807,26 @@
 static void do_echo(st_command* command)
 {
   string ds_echo;
-
-
   do_eval(&ds_echo, command->first_argument, command->end, false);
   ds_res.append(ds_echo.c_str(), ds_echo.length());
   ds_res.append("\n");
   command->last_argument= command->end;
 }
 
-
 static void do_wait_for_slave_to_stop()
 {
   static int SLAVE_POLL_INTERVAL= 300000;
-  drizzle_con_st *con= &cur_con->con;
+  drizzle::connection_c& con= *cur_con;
   for (;;)
   {
-    drizzle_result_st res;
-    drizzle_return_t ret;
-    drizzle_row_t row;
-    int done;
-
-    if (drizzle_query_str(con,&res,"show status like 'Slave_running'",
-                          &ret) == NULL || ret != DRIZZLE_RETURN_OK)
-    {
-      if (ret == DRIZZLE_RETURN_ERROR_CODE)
-      {
-        die("Query failed while probing slave for stop: %s",
-            drizzle_result_error(&res));
-        drizzle_result_free(&res);
-      }
-      else
-      {
-        die("Query failed while probing slave for stop: %s",
-            drizzle_con_error(con));
-      }
-    }
-
-    if (drizzle_result_column_count(&res) == 0 ||
-        drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-    {
-      die("Query failed while probing slave for stop: %s",
-          drizzle_con_error(con));
-    }
-
-    if (!(row=drizzle_row_next(&res)) || !row[1])
-    {
-      drizzle_result_free(&res);
+    drizzle::result_c res;
+    dt_query(con, res, "show status like 'Slave_running'");
+    drizzle_row_t row= res.row_next();
+    if (!row || !row[1])
+    {
       die("Strange result from query while probing slave for stop");
     }
-    done = !strcmp(row[1],"OFF");
-    drizzle_result_free(&res);
-    if (done)
+    if (!strcmp(row[1], "OFF"))
       break;
     usleep(SLAVE_POLL_INTERVAL);
   }
@@ -2986,10 +2834,7 @@
 
 static void do_sync_with_master2(long offset)
 {
-  drizzle_result_st res;
-  drizzle_return_t ret;
-  drizzle_row_t row;
-  drizzle_con_st *con= &cur_con->con;
+  drizzle::connection_c& con= *cur_con;
   char query_buf[FN_REFLEN+128];
   int tries= 0;
 
@@ -3001,26 +2846,12 @@
 
 wait_for_position:
 
-  if (drizzle_query_str(con, &res, query_buf, &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
-  {
-    if (ret == DRIZZLE_RETURN_ERROR_CODE)
-    {
-      die("failed in '%s': %d: %s", query_buf, drizzle_result_error_code(&res),
-           drizzle_result_error(&res));
-      drizzle_result_free(&res);
-    }
-    else
-      die("failed in '%s': %d: %s", query_buf, ret, drizzle_con_error(con));
-  }
-
-  if (drizzle_result_column_count(&res) == 0 ||
-      drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-    die("drizzle_result_buffer() returned NULL for '%s'", query_buf);
-
-  if (!(row= drizzle_row_next(&res)))
-  {
-    drizzle_result_free(&res);
+  drizzle::result_c res;
+  dt_query(con, res, query_buf);
+
+  drizzle_row_t row= res.row_next();
+  if (!row)
+  {
     die("empty result in %s", query_buf);
   }
   if (!row[0])
@@ -3029,7 +2860,6 @@
       It may be that the slave SQL thread has not started yet, though START
       SLAVE has been issued ?
     */
-    drizzle_result_free(&res);
     if (tries++ == 30)
     {
       show_query(con, "SHOW MASTER STATUS");
@@ -3039,8 +2869,6 @@
     sleep(1); /* So at most we will wait 30 seconds and make 31 tries */
     goto wait_for_position;
   }
-  drizzle_result_free(&res);
-  return;
 }
 
 static void do_sync_with_master(st_command* command)
@@ -3068,34 +2896,16 @@
 */
 static void do_save_master_pos()
 {
-  drizzle_result_st res;
-  drizzle_return_t ret;
-  drizzle_row_t row;
-  drizzle_con_st *con= &cur_con->con;
-  const char *query;
-
-
-  if (drizzle_query_str(con, &res, query= "show master status", &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
-  {
-    if (ret == DRIZZLE_RETURN_ERROR_CODE)
-    {
-      die("failed in '%s': %d: %s", query, drizzle_result_error_code(&res),
-           drizzle_result_error(&res));
-      drizzle_result_free(&res);
-    }
-    else
-      die("failed in '%s': %d: %s", query, ret, drizzle_con_error(con));
-  }
-
-  if (drizzle_result_column_count(&res) == 0 ||
-      drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-    die("drizzleclient_store_result() retuned NULL for '%s'", query);
-  if (!(row = drizzle_row_next(&res)))
+  drizzle::connection_c& con= *cur_con;
+  const char *query= "show master status";
+
+  drizzle::result_c res;
+  dt_query(con, res, query);
+  drizzle_row_t row= res.row_next();
+  if (!row)
     die("empty result in show master status");
   strncpy(master_pos.file, row[0], sizeof(master_pos.file)-1);
   master_pos.pos = strtoul(row[1], (char**) 0, 10);
-  drizzle_result_free(&res);
 }
 
 
@@ -3249,33 +3059,13 @@
 
 static void fill_global_error_names()
 {
-  drizzle_result_st res;
-  drizzle_return_t ret;
-  drizzle_con_st *con= &cur_con->con;
+  drizzle::connection_c& con= *cur_con;
 
   global_error_names.clear();
 
-  const std::string ds_query("select error_name, error_code from data_dictionary.errors");
-  if (drizzle_query_str(con, &res, ds_query.c_str(), &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
-  {
-    if (ret == DRIZZLE_RETURN_ERROR_CODE)
-    {
-      die("Error running query '%s': %d %s", ds_query.c_str(), drizzle_result_error_code(&res), drizzle_result_error(&res));
-    }
-    else
-    {
-      die("Error running query '%s': %d %s", ds_query.c_str(), ret, drizzle_con_error(con));
-    }
-  }
-  if (drizzle_result_column_count(&res) == 0 ||
-      drizzle_result_buffer(&res) != DRIZZLE_RETURN_OK)
-  {
-    drizzle_result_free(&res);
-    die("Query '%s' didn't return a result set", ds_query.c_str());
-  }
-
-  while (drizzle_row_t row= drizzle_row_next(&res))
+  drizzle::result_c res;
+  dt_query(con, res, "select error_name, error_code from data_dictionary.errors");
+  while (drizzle_row_t row= res.row_next())
   {
     if (not row[0])
       break;
@@ -3283,20 +3073,16 @@
       Concatenate all fields in the first row with tab in between
       and assign that string to the $variable
     */
-    size_t *lengths= drizzle_row_field_sizes(&res);
+    size_t *lengths= res.row_field_sizes();
     try
     {
       global_error_names[string(row[0], lengths[0])] = boost::lexical_cast<uint32_t>(string(row[1], lengths[1]));
     }
     catch (boost::bad_lexical_cast &ex)
     {
-      drizzle_result_free(&res);
       die("Invalid error_code from Drizzle: %s", ex.what());
     }
-
   }
-
-  drizzle_result_free(&res);
 }
 
 static uint32_t get_errcode_from_name(const char *error_name, const char *error_end)
@@ -3502,44 +3288,37 @@
 }
 
 
-static int select_connection_name(const char *name)
+static void select_connection_name(const char *name)
 {
-  if (!(cur_con= find_connection_by_name(name)))
+  if (!(cur_con= find_ptr2(g_connections, name)))
     die("connection '%s' not found in connection pool", name);
 
   /* Update $drizzleclient_get_server_version to that of current connection */
-  var_set_drizzleclient_get_server_version(&cur_con->con);
-
-  return(0);
+  var_set_drizzleclient_get_server_version(*cur_con);
 }
 
 
-static int select_connection(st_command* command)
+static void select_connection(st_command* command)
 {
-  char *name;
   char *p= command->first_argument;
-
-
   if (!*p)
     die("Missing connection name in connect");
-  name= p;
+  char* name= p;
   while (*p && !my_isspace(charset_info,*p))
     p++;
   if (*p)
     *p++= 0;
   command->last_argument= p;
-  return(select_connection_name(name));
+  select_connection_name(name);
 }
 
 
 static void do_close_connection(st_command* command)
 {
-  char *p= command->first_argument, *name;
-  st_connection *con;
-
+  char* p= command->first_argument;
   if (!*p)
     die("Missing connection name in disconnect");
-  name= p;
+  char* name= p;
   while (*p && !my_isspace(charset_info,*p))
     p++;
 
@@ -3547,21 +3326,11 @@
     *p++= 0;
   command->last_argument= p;
 
-  if (!(con= find_connection_by_name(name)))
+  st_connection* con= find_ptr2(g_connections, name);
+  if (!con)
     die("connection '%s' not found in connection pool", name);
-
-  if (con->drizzle != NULL)
-  {
-    drizzle_free(con->drizzle);
-    con->drizzle= NULL;
-  }
-  free(con->name);
-
-  /*
-    When the connection is closed set name to "-closed_connection-"
-    to make it possible to reuse the connection name.
-  */
-  con->name = strdup("-closed_connection-");
+  g_connections.erase(name);
+  delete con;
 }
 
 
@@ -3590,18 +3359,15 @@
 
 */
 
-static void safe_connect(drizzle_con_st *con, const char *name,
-                         const string host, const string user, const char *pass,
-                         const string db, uint32_t port)
+static st_connection* safe_connect(const char *name, const string host, const string user, const char *pass, const string db, uint32_t port)
 {
   uint32_t failed_attempts= 0;
-  static uint32_t connection_retry_sleep= 100000; /* Microseconds */
-  drizzle_return_t ret;
-
+  st_connection* con0= new st_connection;
+  drizzle_con_st* con= *con0;
   drizzle_con_set_tcp(con, host.c_str(), port);
   drizzle_con_set_auth(con, user.c_str(), pass);
   drizzle_con_set_db(con, db.c_str());
-  while((ret= drizzle_con_connect(con)) != DRIZZLE_RETURN_OK)
+  while (drizzle_return_t ret= drizzle_con_connect(con))
   {
     /*
       Connect failed
@@ -3615,22 +3381,19 @@
          ret == DRIZZLE_RETURN_COULD_NOT_CONNECT) &&
         failed_attempts < opt_max_connect_retries)
     {
-      verbose_msg("Connect attempt %d/%d failed: %d: %s", failed_attempts,
-                  opt_max_connect_retries, ret, drizzle_con_error(con));
-      usleep(connection_retry_sleep);
+      verbose_msg("Connect attempt %d/%d failed: %d: %s", failed_attempts, opt_max_connect_retries, ret, drizzle_con_error(con));
+      usleep(100000);
     }
     else
     {
       if (failed_attempts > 0)
-        die("Could not open connection '%s' after %d attempts: %d %s", name,
-            failed_attempts, ret, drizzle_con_error(con));
+        die("Could not open connection '%s' after %d attempts: %d %s", name, failed_attempts, ret, drizzle_con_error(con));
       else
-        die("Could not open connection '%s': %d %s", name, ret,
-            drizzle_con_error(con));
+        die("Could not open connection '%s': %d %s", name, ret, drizzle_con_error(con));
     }
     failed_attempts++;
   }
-  return;
+  return con0;
 }
 
 
@@ -3662,8 +3425,6 @@
                                    const char* user, const char* pass,
                                    const char* db, int port, const char* sock)
 {
-  drizzle_return_t ret;
-
   /* Only log if an error is expected */
   if (!command->abort_on_error &&
       !disable_query_log)
@@ -3692,23 +3453,20 @@
   drizzle_con_set_tcp(con, host, port);
   drizzle_con_set_auth(con, user, pass);
   drizzle_con_set_db(con, db);
-  if ((ret= drizzle_con_connect(con)) != DRIZZLE_RETURN_OK)
+  if (drizzle_return_t ret= drizzle_con_connect(con))
   {
     if (ret == DRIZZLE_RETURN_HANDSHAKE_FAILED)
     {
       var_set_errno(drizzle_con_error_code(con));
-      handle_error(command, drizzle_con_error_code(con), drizzle_con_error(con),
-                   drizzle_con_sqlstate(con), &ds_res);
+      handle_error(command, drizzle_con_error_code(con), drizzle_con_error(con), drizzle_con_sqlstate(con), &ds_res);
     }
     else
     {
       var_set_errno(ret);
       handle_error(command, ret, drizzle_con_error(con), "", &ds_res);
     }
-
     return 0; /* Not connected */
   }
-
   var_set_errno(0);
   handle_no_error(command);
   return 1; /* Connected */
@@ -3743,8 +3501,6 @@
 static void do_connect(st_command* command)
 {
   uint32_t con_port= opt_port;
-  const char *con_options;
-  st_connection* con_slot;
 
   string ds_connection_name;
   string ds_host;
@@ -3765,7 +3521,6 @@
     { "options", ARG_STRING, false, &ds_options, "Options to use while connecting" }
   };
 
-
   strip_parentheses(command);
   check_command_args(command, command->first_argument, connect_args,
                      sizeof(connect_args)/sizeof(struct command_arg),
@@ -3790,77 +3545,52 @@
     {
       char buff[FN_REFLEN];
       internal::fn_format(buff, ds_sock.c_str(), TMPDIR, "", 0);
-      ds_sock.clear();
-      ds_sock.append(buff);
+      ds_sock= buff;
     }
   }
 
   /* Options */
-  con_options= ds_options.c_str();
+  const char* con_options= ds_options.c_str();
   while (*con_options)
   {
-    const char* end;
     /* Step past any spaces in beginning of option*/
     while (*con_options && my_isspace(charset_info, *con_options))
       con_options++;
     /* Find end of this option */
-    end= con_options;
+    const char* end= con_options;
     while (*end && !my_isspace(charset_info, *end))
       end++;
-    die("Illegal option to connect: %.*s",
-        (int) (end - con_options), con_options);
+    die("Illegal option to connect: %.*s", (int) (end - con_options), con_options);
     /* Process next option */
     con_options= end;
   }
 
-  if (find_connection_by_name(ds_connection_name.c_str()))
+  if (find_ptr2(g_connections, ds_connection_name))
     die("Connection %s already exists", ds_connection_name.c_str());
 
-  if (next_con != g_connections + sizeof(g_connections) / sizeof(st_connection) - 1)
-  {
-    con_slot= next_con;
-  }
-  else
-  {
-    if (!(con_slot= find_connection_by_name("-closed_connection-")))
-      die("Connection limit exhausted, you can have max %d connections",
-          (int) (sizeof(g_connections)/sizeof(st_connection)));
-  }
-
-  if ((con_slot->drizzle= drizzle_create(NULL)) == NULL)
-    die("Failed on drizzle_create()");
-  if (!drizzle_con_create(con_slot->drizzle, &con_slot->con))
-    die("Failed on drizzle_con_create()");
-  drizzle_con_add_options(&con_slot->con, use_drizzle_protocol ? DRIZZLE_CON_EXPERIMENTAL : DRIZZLE_CON_MYSQL);
+  st_connection* con_slot= new st_connection;
 
   /* Use default db name */
-  if (ds_database.length() == 0)
-    ds_database.append(opt_db);
+  if (ds_database.empty())
+    ds_database= opt_db;
 
   /* Special database to allow one to connect without a database name */
-  if (ds_database.length() && !strcmp(ds_database.c_str(),"*NO-ONE*"))
+  if (ds_database == "*NO-ONE*")
     ds_database.clear();
 
-  if (connect_n_handle_errors(command, &con_slot->con,
-                              ds_host.c_str(),ds_user.c_str(),
-                              ds_password.c_str(), ds_database.c_str(),
-                              con_port, ds_sock.c_str()))
+  if (connect_n_handle_errors(command, *con_slot, ds_host.c_str(), ds_user.c_str(), 
+    ds_password.c_str(), ds_database.c_str(), con_port, ds_sock.c_str()))
   {
-    con_slot->name= strdup(ds_connection_name.c_str());
+    g_connections[ds_connection_name]= con_slot;
     cur_con= con_slot;
-
-    if (con_slot == next_con)
-      next_con++; /* if we used the next_con slot, advance the pointer */
   }
 
   /* Update $drizzleclient_get_server_version to that of current connection */
-  var_set_drizzleclient_get_server_version(&cur_con->con);
-
-  return;
+  var_set_drizzleclient_get_server_version(*cur_con);
 }
 
 
-static int do_done(st_command* command)
+static void do_done(st_command* command)
 {
   /* Check if empty block stack */
   if (cur_block == block_stack)
@@ -3883,7 +3613,6 @@
     cur_block--;
     parser.current_line++;
   }
-  return 0;
 }
 
 
@@ -3913,7 +3642,7 @@
 
 */
 
-static void do_block(enum block_cmd cmd, struct st_command* command)
+static void do_block(enum block_cmd cmd, st_command* command)
 {
   char *p= command->first_argument;
   const char *expr_start, *expr_end;
@@ -3973,12 +3702,10 @@
 
   free(v.str_val);
   free(v.env_s);
-
-  return;
 }
 
 
-static void do_delimiter(struct st_command* command)
+static void do_delimiter(st_command* command)
 {
   char* p= command->first_argument;
 
@@ -3992,7 +3719,6 @@
   delimiter_length= strlen(delimiter);
 
   command->last_argument= p + delimiter_length;
-  return;
 }
 
 
@@ -4306,7 +4032,7 @@
 {
   const char *ptr= command->query;
 
-  while(*ptr)
+  while (*ptr)
   {
     /*
       Look for query's that lines that start with a -- comment
@@ -4331,15 +4057,11 @@
       *end= 0;
       type= command_typelib.find_type(start, TYPELIB::e_default);
       if (type)
-        warning_msg("Embedded drizzletest command '--%s' detected in "
-                    "query '%s' was this intentional? ",
-                    start, command->query);
+        warning_msg("Embedded drizzletest command '--%s' detected in query '%s' was this intentional? ", start, command->query);
       *end= save;
     }
-
     ptr++;
   }
-  return;
 }
 
 /*
@@ -4414,10 +4136,10 @@
 #define MAX_QUERY (768*1024*2) /* 256K -- a test in sp-big is >128K */
 static char read_command_buf[MAX_QUERY];
 
-static int read_command(struct st_command** command_ptr)
+static int read_command(st_command** command_ptr)
 {
   char *p= read_command_buf;
-  struct st_command* command;
+  st_command* command;
 
 
   if (parser.current_line < parser.read_lines)
@@ -4485,9 +4207,7 @@
 
 void str_to_file2(const char *fname, const char *str, int size, bool append)
 {
-  int fd;
   char buff[FN_REFLEN];
-  int flags= O_WRONLY | O_CREAT;
   if (!internal::test_if_hard_path(fname))
   {
     snprintf(buff, sizeof(buff), "%s%s",opt_basedir.c_str(),fname);
@@ -4495,10 +4215,11 @@
   }
   internal::fn_format(buff, fname, "", "", MY_UNPACK_FILENAME);
 
+  int flags= O_WRONLY | O_CREAT;
   if (!append)
     flags|= O_TRUNC;
-  if ((fd= internal::my_open(buff, flags,
-                   MYF(MY_WME | MY_FFNF))) < 0)
+  int fd= internal::my_open(buff, flags, MYF(MY_WME | MY_FFNF));
+  if (fd < 0)
     die("Could not open '%s' for writing: errno = %d", buff, errno);
   if (append && lseek(fd, 0, SEEK_END) == MY_FILEPOS_ERROR)
     die("Could not find end of file '%s': errno = %d", buff, errno);
@@ -4530,8 +4251,7 @@
                         ! opt_logdir.empty() ? MY_REPLACE_DIR | MY_REPLACE_EXT :
                         MY_REPLACE_EXT),
               buf, size);
-  fprintf(stderr, "\nMore results from queries before failure can be found in %s\n",
-          log_file);
+  fprintf(stderr, "\nMore results from queries before failure can be found in %s\n", log_file);
 }
 
 void dump_progress()
@@ -4577,13 +4297,13 @@
   {
     if (col_idx)
       ds->append("\t");
-    replace_append_mem(ds, val, (int)len);
+    replace_append_mem(*ds, val, (int)len);
   }
   else
   {
     ds->append(drizzle_column_name(column));
     ds->append("\t");
-    replace_append_mem(ds, val, (int)len);
+    replace_append_mem(*ds, val, (int)len);
     ds->append("\n");
   }
 }
@@ -4594,26 +4314,21 @@
   Values may be converted with 'replace_column'
 */
 
-static void append_result(string *ds, drizzle_result_st *res)
+static void append_result(string *ds, drizzle::result_c& res)
 {
-  drizzle_row_t row;
-  uint32_t num_fields= drizzle_result_column_count(res);
-  drizzle_column_st *column;
-  size_t *lengths;
-
-  while ((row = drizzle_row_next(res)))
+  uint32_t num_fields= res.column_count();
+  while (drizzle_row_t row = res.row_next())
   {
-    uint32_t i;
-    lengths = drizzle_row_field_sizes(res);
-    drizzle_column_seek(res, 0);
-    for (i = 0; i < num_fields; i++)
+    size_t* lengths = res.row_field_sizes();
+    res.column_seek(0);
+    for (uint32_t i = 0; i < num_fields; i++)
     {
-      column= drizzle_column_next(res);
-      if (row[i] && (drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_TINY))
+      drizzle_column_st* column= res.column_next();
+      if (row[i] && drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_TINY)
       {
         if (boost::lexical_cast<uint32_t>(row[i]))
         {
-          if ((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_UNSIGNED))
+          if (drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_UNSIGNED)
           {
             append_field(ds, i, column, "YES", 3, false);
           }
@@ -4624,7 +4339,7 @@
         }
         else
         {
-          if ((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_UNSIGNED))
+          if (drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_UNSIGNED)
           {
             append_field(ds, i, column, "NO", 2, false);
           }
@@ -4636,13 +4351,11 @@
       }
       else
       {
-        append_field(ds, i, column,
-                     (const char*)row[i], lengths[i], !row[i]);
+        append_field(ds, i, column, (const char*)row[i], lengths[i], !row[i]);
       }
     }
     if (!display_result_vertically)
       ds->append("\n");
-
   }
 }
 
@@ -4651,54 +4364,41 @@
   Append metadata for fields to output
 */
 
-static void append_metadata(string *ds, drizzle_result_st *res)
+static void append_metadata(string *ds, drizzle::result_c& res)
 {
-  drizzle_column_st *column;
   ds->append("Catalog\tDatabase\tTable\tTable_alias\tColumn\t"
              "Column_alias\tType\tLength\tMax length\tIs_null\t"
              "Flags\tDecimals\tCharsetnr\n");
 
-  drizzle_column_seek(res, 0);
-  while ((column= drizzle_column_next(res)))
+  res.column_seek(0);
+  while (drizzle_column_st* column= res.column_next())
   {
-    ds->append(drizzle_column_catalog(column),
-               strlen(drizzle_column_catalog(column)));
-    ds->append("\t", 1);
+    ds->append(drizzle_column_catalog(column), strlen(drizzle_column_catalog(column)));
+    *ds += "\t";
     ds->append(drizzle_column_db(column), strlen(drizzle_column_db(column)));
-    ds->append("\t", 1);
-    ds->append(drizzle_column_orig_table(column),
-               strlen(drizzle_column_orig_table(column)));
-    ds->append("\t", 1);
-    ds->append(drizzle_column_table(column),
-               strlen(drizzle_column_table(column)));
-    ds->append("\t", 1);
-    ds->append(drizzle_column_orig_name(column),
-               strlen(drizzle_column_orig_name(column)));
-    ds->append("\t", 1);
-    ds->append(drizzle_column_name(column),
-               strlen(drizzle_column_name(column)));
-    ds->append("\t", 1);
+    *ds += "\t";
+    ds->append(drizzle_column_orig_table(column), strlen(drizzle_column_orig_table(column)));
+    *ds += "\t";
+    ds->append(drizzle_column_table(column), strlen(drizzle_column_table(column)));
+    *ds += "\t";
+    ds->append(drizzle_column_orig_name(column), strlen(drizzle_column_orig_name(column)));
+    *ds += "\t";
+    ds->append(drizzle_column_name(column), strlen(drizzle_column_name(column)));
+    *ds += "\t";
     replace_append_uint(ds, drizzle_column_type_drizzle(column));
-    ds->append("\t", 1);
+    *ds += "\t";
     replace_append_uint(ds, drizzle_column_size(column));
-    ds->append("\t", 1);
-    if (drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_TINY)
-    {
-      replace_append_uint(ds, 1);
-    }
-    else
-    {
-      replace_append_uint(ds, drizzle_column_max_size(column));
-    }
-    ds->append("\t", 1);
-    ds->append((char*) ((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_NOT_NULL) ? "N" : "Y"), 1);
-    ds->append("\t", 1);
+    *ds += "\t";
+    replace_append_uint(ds, drizzle_column_type(column) == DRIZZLE_COLUMN_TYPE_TINY ? 1 : drizzle_column_max_size(column));
+    *ds += "\t";
+    ds->append((drizzle_column_flags(column) & DRIZZLE_COLUMN_FLAGS_NOT_NULL) ? "N" : "Y", 1);
+    *ds += "\t";
     replace_append_uint(ds, drizzle_column_flags(column));
-    ds->append("\t", 1);
+    *ds += "\t";
     replace_append_uint(ds, drizzle_column_decimals(column));
-    ds->append("\t", 1);
+    *ds += "\t";
     replace_append_uint(ds, drizzle_column_charset(column));
-    ds->append("\n", 1);
+    *ds += "\n";
   }
 }
 
@@ -4726,19 +4426,18 @@
   Display the table headings with the names tab separated
 */
 
-static void append_table_headings(string *ds, drizzle_result_st *res)
+static void append_table_headings(string& ds, drizzle::result_c& res)
 {
   uint32_t col_idx= 0;
-  drizzle_column_st *column;
-  drizzle_column_seek(res, 0);
-  while ((column= drizzle_column_next(res)))
+  res.column_seek(0);
+  while (drizzle_column_st* column= res.column_next())
   {
     if (col_idx)
-      ds->append("\t", 1);
-    replace_append(ds, drizzle_column_name(column));
+      ds += "\t";
+    replace_append(&ds, drizzle_column_name(column));
     col_idx++;
   }
-  ds->append("\n", 1);
+  ds += "\n";
 }
 
 /*
@@ -4748,34 +4447,16 @@
   Number of warnings appended to ds
 */
 
-static int append_warnings(string *ds, drizzle_con_st *con,
-                           drizzle_result_st *res)
+static int append_warnings(string& ds, drizzle::connection_c& con, drizzle::result_c& res)
 {
-  uint32_t count;
-  drizzle_result_st warn_res;
-  drizzle_return_t ret;
-
-
-  if (!(count= drizzle_result_warning_count(res)))
-    return(0);
-
-  if (drizzle_query_str(con, &warn_res, "SHOW WARNINGS", &ret) == NULL ||
-      ret != DRIZZLE_RETURN_OK)
-  {
-    if (ret == DRIZZLE_RETURN_ERROR_CODE)
-      die("Error running query \"SHOW WARNINGS\": %s", drizzle_result_error(&warn_res));
-    else
-      die("Error running query \"SHOW WARNINGS\": %s", drizzle_con_error(con));
-  }
-
-  if (drizzle_result_column_count(&warn_res) == 0 ||
-      drizzle_result_buffer(&warn_res) != DRIZZLE_RETURN_OK)
-    die("Warning count is %u but didn't get any warnings", count);
-
-  append_result(ds, &warn_res);
-  drizzle_result_free(&warn_res);
-
-  return(count);
+  uint32_t count= drizzle_result_warning_count(&res.b_);
+  if (!count)
+    return 0;
+
+  drizzle::result_c warn_res;
+  dt_query(con, warn_res, "show warnings");
+  append_result(&ds, warn_res);
+  return count;
 }
 
 
@@ -4792,35 +4473,32 @@
   ds    output buffer where to store result form query
 */
 
-static void run_query_normal(st_connection *cn,
+static void run_query_normal(st_connection& cn,
                              st_command* command,
                              int flags, char *query, int query_len,
-                             string *ds, string *ds_warnings)
+                             string *ds, string& ds_warnings)
 {
-  drizzle_result_st res;
   drizzle_return_t ret;
-  drizzle_con_st *con= &cn->con;
+  drizzle_con_st *con= cn;
   int err= 0;
 
   drizzle_con_add_options(con, DRIZZLE_CON_NO_RESULT_READ);
 
+  drizzle::result_c res;
   if (flags & QUERY_SEND_FLAG)
   {
     /*
      * Send the query
      */
 
-    (void) drizzle_query(con, &res, query, query_len, &ret);
+    (void) drizzle_query(con, &res.b_, query, query_len, &ret);
     if (ret != DRIZZLE_RETURN_OK)
     {
       if (ret == DRIZZLE_RETURN_ERROR_CODE ||
           ret == DRIZZLE_RETURN_HANDSHAKE_FAILED)
       {
-        err= drizzle_result_error_code(&res);
-        handle_error(command, err, drizzle_result_error(&res),
-                     drizzle_result_sqlstate(&res), ds);
-        if (ret == DRIZZLE_RETURN_ERROR_CODE)
-          drizzle_result_free(&res);
+        err= res.error_code();
+        handle_error(command, err, res.error(), drizzle_result_sqlstate(&res.b_), ds);
       }
       else
       {
@@ -4837,18 +4515,15 @@
     /*
      * Read the result packet
      */
-    if (drizzle_result_read(con, &res, &ret) == NULL ||
+    if (drizzle_result_read(con, &res.b_, &ret) == NULL ||
         ret != DRIZZLE_RETURN_OK)
     {
       if (ret == DRIZZLE_RETURN_ERROR_CODE)
       {
-        handle_error(command, drizzle_result_error_code(&res),
-                     drizzle_result_error(&res), drizzle_result_sqlstate(&res),
-                     ds);
+        handle_error(command, res.error_code(), res.error(), drizzle_result_sqlstate(&res.b_), ds);
       }
       else
         handle_error(command, ret, drizzle_con_error(con), "", ds);
-      drizzle_result_free(&res);
       err= ret;
       goto end;
     }
@@ -4856,18 +4531,15 @@
     /*
       Store the result of the query if it will return any fields
     */
-    if (drizzle_result_column_count(&res) &&
-        (ret= drizzle_result_buffer(&res)) != DRIZZLE_RETURN_OK)
+    if (res.column_count() &&
+        (ret= drizzle_result_buffer(&res.b_)) != DRIZZLE_RETURN_OK)
     {
       if (ret == DRIZZLE_RETURN_ERROR_CODE)
       {
-        handle_error(command, drizzle_result_error_code(&res),
-                     drizzle_result_error(&res), drizzle_result_sqlstate(&res),
-                     ds);
+        handle_error(command, res.error_code(), res.error(), drizzle_result_sqlstate(&res.b_), ds);
       }
       else
         handle_error(command, ret, drizzle_con_error(con), "", ds);
-      drizzle_result_free(&res);
       err= ret;
       goto end;
     }
@@ -4876,15 +4548,15 @@
     {
       uint64_t affected_rows= 0;    /* Ok to be undef if 'disable_info' is set */
 
-      if (drizzle_result_column_count(&res))
+      if (res.column_count())
       {
         if (display_metadata)
-          append_metadata(ds, &res);
+          append_metadata(ds, res);
 
         if (!display_result_vertically)
-          append_table_headings(ds, &res);
+          append_table_headings(*ds, res);
 
-        append_result(ds, &res);
+        append_result(ds, res);
       }
 
       /*
@@ -4892,7 +4564,7 @@
         query to find the warnings
       */
       if (!disable_info)
-        affected_rows= drizzle_result_affected_rows(&res);
+        affected_rows= drizzle_result_affected_rows(&res.b_);
 
       /*
         Add all warnings to the result. We can't do this if we are in
@@ -4902,18 +4574,17 @@
       if (!disable_warnings)
       {
         drizzle_con_remove_options(con, DRIZZLE_CON_NO_RESULT_READ);
-        if (append_warnings(ds_warnings, con, &res) || ds_warnings->length())
+        if (append_warnings(ds_warnings, cn, res) || not ds_warnings.empty())
         {
           ds->append("Warnings:\n", 10);
-          ds->append(ds_warnings->c_str(), ds_warnings->length());
+          *ds += ds_warnings;
         }
       }
 
       if (!disable_info)
-        append_info(ds, affected_rows, drizzle_result_info(&res));
+        append_info(ds, affected_rows, drizzle_result_info(&res.b_));
     }
 
-    drizzle_result_free(&res);
   }
 
   /* If we come here the query is both executed and read successfully */
@@ -4928,7 +4599,6 @@
   */
   drizzle_con_remove_options(con, DRIZZLE_CON_NO_RESULT_READ);
   var_set_errno(err);
-  return;
 }
 
 
@@ -4952,9 +4622,6 @@
                   unsigned int err_errno, const char *err_error,
                   const char *err_sqlstate, string *ds)
 {
-  uint32_t i;
-
-
   if (! command->require_file.empty())
   {
     /*
@@ -4963,18 +4630,17 @@
       abort_not_supported_test
     */
     if (err_errno == DRIZZLE_RETURN_SERVER_GONE)
-      die("require query '%s' failed: %d: %s", command->query,
-          err_errno, err_error);
+      die("require query '%s' failed: %d: %s", command->query, err_errno, err_error);
 
     /* Abort the run of this test, pass the failed query as reason */
-    abort_not_supported_test("Query '%s' failed, required functionality " \
-                             "not supported", command->query);
+    abort_not_supported_test("Query '%s' failed, required functionality not supported", command->query);
   }
 
   if (command->abort_on_error)
     die("query '%s' failed: %d: %s", command->query, err_errno, err_error);
 
-  for (i= 0 ; (uint32_t) i < command->expected_errors.count ; i++)
+  uint32_t i= 0;
+  for (; i < command->expected_errors.count; i++)
   {
     if (((command->expected_errors.err[i].type == ERR_ERRNO) &&
          (command->expected_errors.err[i].code.errnum == err_errno)) ||
@@ -5024,8 +4690,6 @@
           command->query, err_sqlstate, err_error,
           command->expected_errors.err[0].code.sqlstate);
   }
-
-  return;
 }
 
 
@@ -5042,24 +4706,18 @@
 
 void handle_no_error(st_command* command)
 {
-
-
   if (command->expected_errors.err[0].type == ERR_ERRNO &&
       command->expected_errors.err[0].code.errnum != 0)
   {
     /* Error code we wanted was != 0, i.e. not an expected success */
-    die("query '%s' succeeded - should have failed with errno %d...",
-        command->query, command->expected_errors.err[0].code.errnum);
+    die("query '%s' succeeded - should have failed with errno %d...", command->query, command->expected_errors.err[0].code.errnum);
   }
   else if (command->expected_errors.err[0].type == ERR_SQLSTATE &&
            strcmp(command->expected_errors.err[0].code.sqlstate,"00000") != 0)
   {
     /* SQLSTATE we wanted was != "00000", i.e. not an expected success */
-    die("query '%s' succeeded - should have failed with sqlstate %s...",
-        command->query, command->expected_errors.err[0].code.sqlstate);
+    die("query '%s' succeeded - should have failed with sqlstate %s...", command->query, command->expected_errors.err[0].code.sqlstate);
   }
-
-  return;
 }
 
 
@@ -5076,15 +4734,10 @@
   is on the result will be read - for regular query, both bits must be on
 */
 
-static void run_query(st_connection *cn,
+static void run_query(st_connection& cn,
                       st_command* command,
                       int flags)
 {
-  string *ds= NULL;
-  string *save_ds= NULL;
-  string ds_result;
-  string ds_sorted;
-  string ds_warnings;
   string eval_query;
   char *query;
   int query_len;
@@ -5114,24 +4767,20 @@
     Create a temporary dynamic string to contain the output from
     this query.
   */
-  if (! command->require_file.empty())
-  {
-    ds= &ds_result;
-  }
-  else
-  {
-    ds= &ds_res;
-  }
+  string ds_result;
+  string* ds= command->require_file.empty() ? &ds_res : &ds_result;
   /*
     Log the query into the output buffer
   */
   if (!disable_query_log && (flags & QUERY_SEND_FLAG))
   {
-    replace_append_mem(ds, query, query_len);
+    replace_append_mem(*ds, query, query_len);
     ds->append(delimiter, delimiter_length);
     ds->append("\n");
   }
 
+  string* save_ds= NULL;
+  string ds_sorted;
   if (display_result_sorted)
   {
     /*
@@ -5147,13 +4796,13 @@
     Always run with normal C API if it's not a complete
     SEND + REAP
   */
-  run_query_normal(cn, command, flags, query, query_len,
-                   ds, &ds_warnings);
+  string ds_warnings;
+  run_query_normal(cn, command, flags, query, query_len, ds, ds_warnings);
 
   if (display_result_sorted)
   {
     /* Sort the result set and append it to result */
-    append_sorted(save_ds, &ds_sorted);
+    append_sorted(*save_ds, ds_sorted);
     ds= save_ds;
   }
 
@@ -5163,30 +4812,24 @@
        and the output should be checked against an already
        existing file which has been specified using --require or --result
     */
-    check_require(ds, command->require_file);
+    check_require(*ds, command->require_file);
   }
-
-  return;
 }
 
 
 /****************************************************************************/
 
-static void get_command_type(struct st_command* command)
+static void get_command_type(st_command* command)
 {
-  char save;
-  uint32_t type;
-
-
   if (*command->query == '}')
   {
     command->type = Q_END_BLOCK;
     return;
   }
 
-  save= command->query[command->first_word_len];
+  char save= command->query[command->first_word_len];
   command->query[command->first_word_len]= 0;
-  type= command_typelib.find_type(command->query, TYPELIB::e_default);
+  uint32_t type= command_typelib.find_type(command->query, TYPELIB::e_default);
   command->query[command->first_word_len]= save;
   if (type > 0)
   {
@@ -5239,12 +4882,8 @@
   }
 
   /* Set expected error on command */
-  memcpy(&command->expected_errors, &saved_expected_errors,
-         sizeof(saved_expected_errors));
-  command->abort_on_error= (command->expected_errors.count == 0 &&
-                            abort_on_error);
-
-  return;
+  memcpy(&command->expected_errors, &saved_expected_errors, sizeof(saved_expected_errors));
+  command->abort_on_error= (command->expected_errors.count == 0 && abort_on_error);
 }
 
 
@@ -5258,7 +4897,7 @@
 
 */
 
-static void mark_progress(struct st_command*, int line)
+static void mark_progress(st_command*, int line)
 {
   uint64_t timer= timer_now();
   if (!progress_start)
@@ -5316,11 +4955,9 @@
 {
 try
 {
-  st_command* command;
   bool q_send_flag= 0, abort_flag= 0;
   uint32_t command_executed= 0, last_command_executed= 0;
-  string save_file("");
-  struct stat res_info;
+  string save_file;
 
   TMPDIR[0]= 0;
 
@@ -5444,10 +5081,6 @@
   /* Init expected errors */
   memset(&saved_expected_errors, 0, sizeof(saved_expected_errors));
 
-  /* Init g_connections */
-  memset(g_connections, 0, sizeof(g_connections));
-  next_con= g_connections + 1;
-
   /* Init file stack */
   memset(file_stack.data(), 0, sizeof(file_stack));
   cur_file= file_stack.data();
@@ -5596,16 +5229,8 @@
     cur_file->file_name= strdup("<stdin>");
     cur_file->lineno= 1;
   }
-  cur_con= g_connections;
-  if ((cur_con->drizzle= drizzle_create(NULL)) == NULL)
-    die("Failed in drizzle_create()");
-  if (!( drizzle_con_create(cur_con->drizzle, &cur_con->con)))
-    die("Failed in drizzle_con_create()");
-  drizzle_con_add_options(&cur_con->con, use_drizzle_protocol ? DRIZZLE_CON_EXPERIMENTAL : DRIZZLE_CON_MYSQL);
-
-  cur_con->name = strdup("default");
-  safe_connect(&cur_con->con, cur_con->name, opt_host, opt_user, opt_pass,
-               opt_db, opt_port);
+  cur_con= safe_connect("default", opt_host, opt_user, opt_pass, opt_db, opt_port);
+  g_connections["default"] = cur_con;
 
   fill_global_error_names();
 
@@ -5620,13 +5245,14 @@
   var_set_errno(-1);
 
   /* Update $drizzleclient_get_server_version to that of current connection */
-  var_set_drizzleclient_get_server_version(&cur_con->con);
+  var_set_drizzleclient_get_server_version(*cur_con);
 
   if (! opt_include.empty())
   {
     open_file(opt_include.c_str());
   }
 
+  st_command* command;
   while (!read_command(&command) && !abort_flag)
   {
     int current_line_inc = 1, processed = 0;
@@ -5743,7 +5369,7 @@
           command->require_file= save_file;
           save_file.clear();
         }
-        run_query(cur_con, command, flags);
+        run_query(*cur_con, command, flags);
         command_executed++;
         command->last_argument= command->end;
 
@@ -5773,7 +5399,7 @@
           the query and read the result some time later when reap instruction
           is given on this connection.
         */
-        run_query(cur_con, command, QUERY_SEND_FLAG);
+        run_query(*cur_con, command, QUERY_SEND_FLAG);
         command_executed++;
         command->last_argument= command->end;
         break;
@@ -5809,11 +5435,9 @@
         break;
       case Q_PING:
         {
-          drizzle_result_st result;
+          drizzle::result_c result;
           drizzle_return_t ret;
-          (void) drizzle_ping(&cur_con->con, &result, &ret);
-          if (ret == DRIZZLE_RETURN_OK || ret == DRIZZLE_RETURN_ERROR_CODE)
-            drizzle_result_free(&result);
+          (void) drizzle_ping(*cur_con, &result.b_, &ret);
         }
         break;
       case Q_EXEC:
@@ -5832,10 +5456,10 @@
         do_set_charset(command);
         break;
       case Q_DISABLE_RECONNECT:
-        set_reconnect(&cur_con->con, 0);
+        set_reconnect(*cur_con, 0);
         break;
       case Q_ENABLE_RECONNECT:
-        set_reconnect(&cur_con->con, 1);
+        set_reconnect(*cur_con, 1);
         break;
       case Q_DISABLE_PARSING:
         if (parsing_disabled == 0)
@@ -5928,7 +5552,7 @@
   */
   if (ds_res.length())
   {
-    if (! result_file_name.empty())
+    if (not result_file_name.empty())
     {
       /* A result file has been specified */
 
@@ -5943,7 +5567,7 @@
            - detect missing result file
            - detect zero size result file
         */
-        check_result(&ds_res);
+        check_result(ds_res);
       }
     }
     else
@@ -5957,8 +5581,8 @@
     die("The test didn't produce any output");
   }
 
-  if (!command_executed &&
-      ! result_file_name.empty() && !stat(result_file_name.c_str(), &res_info))
+  struct stat res_info;
+  if (!command_executed && not result_file_name.empty() && not stat(result_file_name.c_str(), &res_info))
   {
     /*
       my_stat() successful on result file. Check if we have not run a
@@ -6085,7 +5709,7 @@
 
 void free_replace_column()
 {
-  for (uint32_t i= 0 ; i < max_replace_column; i++)
+  for (uint32_t i= 0; i < max_replace_column; i++)
   {
     free(replace_column[i]);
     replace_column[i]= 0;
@@ -6125,8 +5749,7 @@
 struct st_replace *init_replace(const char **from, const char **to, uint32_t count,
                                 char *word_end_chars);
 
-void replace_strings_append(struct st_replace *rep, string* ds,
-                            const char *from, int len);
+void replace_strings_append(struct st_replace *rep, string& ds, const char *from, int len);
 
 st_replace *glob_replace= NULL;
 // boost::scoped_ptr<st_replace> glob_replace;
@@ -6206,16 +5829,13 @@
 } REPLACE_STRING;
 
 
-void replace_strings_append(REPLACE *rep, string* ds,
-                            const char *str, int len)
+void replace_strings_append(REPLACE *rep, string& ds, const char *str, int len)
 {
-  REPLACE *rep_pos;
   REPLACE_STRING *rep_str;
-  const char *start, *from;
-
-
-  start= from= str;
-  rep_pos=rep+1;
+  const char* start= str;
+  const char* from= str;
+
+  REPLACE* rep_pos=rep+1;
   for (;;)
   {
     /* Loop through states */
@@ -6226,16 +5846,15 @@
     if (!(rep_str = ((REPLACE_STRING*) rep_pos))->replace_string)
     {
       /* No match found */
-      ds->append(start, from - start - 1);
+      ds.append(start, from - start - 1);
       return;
     }
 
     /* Append part of original string before replace string */
-    ds->append(start, (from - rep_str->to_offset) - start);
+    ds.append(start, (from - rep_str->to_offset) - start);
 
     /* Append replace string */
-    ds->append(rep_str->replace_string,
-               strlen(rep_str->replace_string));
+    ds.append(rep_str->replace_string, strlen(rep_str->replace_string));
 
     if (!*(from-=rep_str->from_offset) && rep_pos->found != 2)
       return;
@@ -6640,7 +6259,7 @@
 
 static bool start_at_word(const char *pos)
 {
-  return ((!memcmp(pos, "\\b",2) && pos[2]) || !memcmp(pos, "\\^", 2));
+  return (!memcmp(pos, "\\b",2) && pos[2]) || !memcmp(pos, "\\^", 2);
 }
 
 static bool end_of_word(const char *pos)
@@ -6663,7 +6282,7 @@
   char *to_pos, **to_array;
 
   /* Count number of states */
-  for (i=result_len=max_length=0 , states=2 ; i < count ; i++)
+  for (i=result_len=max_length=0 , states=2; i < count; i++)
   {
     len=replace_len(from[i]);
     if (!len)
@@ -6677,7 +6296,7 @@
       max_length=len;
   }
   memset(is_word_end, 0, sizeof(is_word_end));
-  for (i=0 ; word_end_chars[i] ; i++)
+  for (i=0; word_end_chars[i]; i++)
     is_word_end[(unsigned char) word_end_chars[i]]=1;
 
   REP_SETS sets;
@@ -6724,7 +6343,7 @@
         start_states->internal_set_bit(states);
     }
     const char *pos;
-    for (pos= from[i], len=0; *pos ; pos++)
+    for (pos= from[i], len=0; *pos; pos++)
     {
       if (*pos == '\\' && *(pos+1))
       {
@@ -6767,14 +6386,14 @@
   }
 
 
-  for (set_nr=0; set_nr < sets.count ; set_nr++)
+  for (set_nr=0; set_nr < sets.count; set_nr++)
   {
     set=sets.set+set_nr;
     default_state= 0;        /* Start from beginning */
 
     /* If end of found-string not found or start-set with current set */
 
-    for (i= UINT32_MAX; (i= set->get_next_bit(i)) ;)
+    for (i= UINT32_MAX; (i= set->get_next_bit(i));)
     {
       if (!follow[i].chr && !default_state)
         default_state= find_found(&found_set.front(), set->table_offset, set->found_offset+1);
@@ -6785,7 +6404,7 @@
 
     /* Find all chars that follows current sets */
     memset(used_chars, 0, sizeof(used_chars));
-    for (i= UINT32_MAX; (i= sets.set[used_sets].get_next_bit(i)) ;)
+    for (i= UINT32_MAX; (i= sets.set[used_sets].get_next_bit(i));)
     {
       used_chars[follow[i].chr]=1;
       if ((follow[i].chr == SPACE_CHAR && !follow[i+1].chr &&
@@ -6795,11 +6414,11 @@
 
     /* Mark word_chars used if \b is in state */
     if (used_chars[SPACE_CHAR])
-      for (const char *pos= word_end_chars ; *pos ; pos++)
+      for (const char *pos= word_end_chars; *pos; pos++)
         used_chars[(int) (unsigned char) *pos] = 1;
 
     /* Handle other used characters */
-    for (chr= 0 ; chr < 256 ; chr++)
+    for (chr= 0; chr < 256; chr++)
     {
       if (! used_chars[chr])
         set->next[chr]= chr ? default_state : -1;
@@ -6812,7 +6431,7 @@
         new_set->found_offset=set->found_offset+1;
         found_end=0;
 
-        for (i= UINT32_MAX ; (i= sets.set[used_sets].get_next_bit(i)) ; )
+        for (i= UINT32_MAX; (i= sets.set[used_sets].get_next_bit(i));)
         {
           if (!follow[i].chr || follow[i].chr == chr ||
               (follow[i].chr == SPACE_CHAR &&
@@ -6833,7 +6452,7 @@
         {
           new_set->found_len=0;      /* Set for testing if first */
           bits_set=0;
-          for (i= UINT32_MAX; (i= new_set->get_next_bit(i)) ;)
+          for (i= UINT32_MAX; (i= new_set->get_next_bit(i));)
           {
             if ((follow[i].chr == SPACE_CHAR ||
                  follow[i].chr == END_OF_LINE) && ! chr)
@@ -6882,14 +6501,14 @@
     rep_str=(REPLACE_STRING*) (replace+sets.count);
     to_array= (char **) (rep_str+found_sets+1);
     to_pos=(char *) (to_array+count);
-    for (i=0 ; i < count ; i++)
+    for (i=0; i < count; i++)
     {
       to_array[i]=to_pos;
       to_pos=strcpy(to_pos,to[i])+strlen(to[i])+1;
     }
     rep_str[0].found=1;
     rep_str[0].replace_string=0;
-    for (i=1 ; i <= found_sets ; i++)
+    for (i=1; i <= found_sets; i++)
     {
       const char *pos= from[found_set[i-1].table_offset];
       rep_str[i].found= !memcmp(pos, "\\^", 3) ? 2 : 1;
@@ -6897,9 +6516,9 @@
       rep_str[i].to_offset= found_set[i-1].found_offset-start_at_word(pos);
       rep_str[i].from_offset= found_set[i-1].found_offset-replace_len(pos) + end_of_word(pos);
     }
-    for (i=0 ; i < sets.count ; i++)
+    for (i=0; i < sets.count; i++)
     {
-      for (j=0 ; j < 256 ; j++)
+      for (j=0; j < 256; j++)
         if (sets.set[i].next[j] >= 0)
           replace[i].next[j]=replace+sets.set[i].next[j];
         else
@@ -6983,7 +6602,7 @@
 
 void REP_SET::or_bits(const REP_SET *from)
 {
-  for (uint32_t i= 0 ; i < size_of_bits; i++)
+  for (uint32_t i= 0; i < size_of_bits; i++)
     bits[i]|=from->bits[i];
 }
 
@@ -7093,7 +6712,7 @@
     if (new_pos != pa->str)
     {
       ptrdiff_t diff= PTR_BYTE_DIFF(new_pos,pa->str);
-      for (i=0 ; i < pa->typelib.count ; i++)
+      for (i=0; i < pa->typelib.count; i++)
         pa->typelib.type_names[i]= ADD_TO_PTR(pa->typelib.type_names[i],diff,
                                               char*);
       pa->str=new_pos;
@@ -7133,7 +6752,7 @@
 /* Functions that uses replace and replace_regex */
 
 /* Append the string to ds, with optional replace */
-void replace_append_mem(string *ds, const char *val, int len)
+void replace_append_mem(string& ds, const char *val, int len)
 {
   char *v= strdup(val);
 
@@ -7148,14 +6767,14 @@
     replace_strings_append(glob_replace, ds, v, len);
   }
   else
-    ds->append(v, len);
+    ds.append(v, len);
 }
 
 
 /* Append zero-terminated string to ds, with optional replace */
 void replace_append(string *ds, const char *val)
 {
-  replace_append_mem(ds, val, strlen(val));
+  replace_append_mem(*ds, val, strlen(val));
 }
 
 /* Append uint32_t to ds, with optional replace */
@@ -7163,7 +6782,7 @@
 {
   ostringstream buff;
   buff << val;
-  replace_append_mem(ds, buff.str().c_str(), buff.str().size());
+  replace_append_mem(*ds, buff.str().c_str(), buff.str().size());
 
 }
 
@@ -7182,40 +6801,37 @@
 */
 
 
-void append_sorted(string* ds, string *ds_input)
+void append_sorted(string& ds, const string& ds_input)
 {
   priority_queue<string, vector<string>, greater<string> > lines;
 
-  if (ds_input->empty())
+  if (ds_input.empty())
     return;  /* No input */
 
-  unsigned long eol_pos= 0;
-
-  eol_pos= ds_input->find_first_of('\n', 0);
+  unsigned long eol_pos= ds_input.find_first_of('\n', 0);
   if (eol_pos == string::npos)
     return; // We should have at least one header here
 
-  ds->append(ds_input->substr(0, eol_pos+1));
+  ds.append(ds_input.substr(0, eol_pos+1));
 
   unsigned long start_pos= eol_pos+1;
 
   /* Insert line(s) in array */
   do {
 
-    eol_pos= ds_input->find_first_of('\n', start_pos);
+    eol_pos= ds_input.find_first_of('\n', start_pos);
     /* Find end of line */
-    lines.push(ds_input->substr(start_pos, eol_pos-start_pos+1));
+    lines.push(ds_input.substr(start_pos, eol_pos-start_pos+1));
     start_pos= eol_pos+1;
 
   } while ( eol_pos != string::npos);
 
   /* Create new result */
-  while (!lines.empty()) {
-    ds->append(lines.top());
+  while (!lines.empty()) 
+  {
+    ds.append(lines.top());
     lines.pop();
   }
-
-  return;
 }
 
 static void free_all_replace()

=== modified file 'drizzled/data_home.cc'
--- drizzled/data_home.cc	2011-02-17 00:14:13 +0000
+++ drizzled/data_home.cc	2011-06-16 15:27:28 +0000
@@ -19,31 +19,44 @@
  */
 
 #include <config.h>
+#include <boost/filesystem.hpp>
 #include <drizzled/configmake.h>
-
-#include <boost/filesystem.hpp>
-
 #include <drizzled/data_home.h>
 
 namespace drizzled {
 
 static boost::filesystem::path data_home(LOCALSTATEDIR);
 static boost::filesystem::path full_data_home(LOCALSTATEDIR);
+static boost::filesystem::path data_home_catalog(LOCALSTATEDIR);
 
-boost::filesystem::path& getFullDataHome()
+const boost::filesystem::path& getFullDataHome()
 {
   return full_data_home;
 }
 
-boost::filesystem::path& getDataHome()
+const boost::filesystem::path& getDataHome()
 {
   return data_home;
 }
 
-boost::filesystem::path& getDataHomeCatalog()
+const boost::filesystem::path& getDataHomeCatalog()
 {
-  static boost::filesystem::path data_home_catalog(getDataHome());
   return data_home_catalog;
 }
 
+boost::filesystem::path& getMutableDataHome()
+{
+  return data_home;
+}
+
+void setFullDataHome(const boost::filesystem::path& v)
+{
+  full_data_home= v;
+}
+
+void setDataHomeCatalog(const boost::filesystem::path& v)
+{
+  data_home_catalog= v;
+}
+
 } // namespace drizzled

=== modified file 'drizzled/data_home.h'
--- drizzled/data_home.h	2011-03-14 05:40:28 +0000
+++ drizzled/data_home.h	2011-06-16 15:27:28 +0000
@@ -17,20 +17,19 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
-
 #pragma once
 
 #include <boost/filesystem.hpp>
-
 #include <drizzled/visibility.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
-DRIZZLED_API boost::filesystem::path& getFullDataHome();
-DRIZZLED_API boost::filesystem::path& getDataHome();
-DRIZZLED_API boost::filesystem::path& getDataHomeCatalog();
+DRIZZLED_API const boost::filesystem::path& getFullDataHome();
+DRIZZLED_API const boost::filesystem::path& getDataHome();
+DRIZZLED_API const boost::filesystem::path& getDataHomeCatalog();
+DRIZZLED_API boost::filesystem::path& getMutableDataHome();
+DRIZZLED_API void setFullDataHome(const boost::filesystem::path&);
+DRIZZLED_API void setDataHomeCatalog(const boost::filesystem::path&);
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-06-13 16:17:54 +0000
+++ drizzled/drizzled.cc	2011-06-16 16:39:05 +0000
@@ -299,12 +299,11 @@
 
 fs::path basedir(PREFIX);
 fs::path pid_file;
-fs::path secure_file_priv("");
+fs::path secure_file_priv;
 fs::path plugin_dir;
 fs::path system_config_dir(SYSCONFDIR);
 
-
-char *opt_tc_log_file;
+const char *opt_tc_log_file;
 const key_map key_map_empty(0);
 key_map key_map_full(0);                        // Will be initialized later
 
@@ -377,23 +376,11 @@
   return vm;
 }
 
-namespace {
-
-std::string &getGlobHostname()
-{
-  static std::string glob_hostname("localhost");
-  return glob_hostname;
-}
-
-void setServerHostname(const std::string &hostname)
-{
-  getGlobHostname()= hostname;
-}
-}
-
-const std::string &getServerHostname()
-{
-  return getGlobHostname();
+static std::string g_hostname= "localhost";
+
+const std::string& getServerHostname()
+{
+  return g_hostname;
 }
 
 /****************************************************************************
@@ -1014,34 +1001,26 @@
 
     ifstream input_defaults_file(file_location.file_string().c_str());
 
-    po::parsed_options file_parsed=
-      dpo::parse_config_file(input_defaults_file, full_options, true);
-    vector<string> file_unknown=
-      po::collect_unrecognized(file_parsed.options, po::include_positional);
+    po::parsed_options file_parsed= dpo::parse_config_file(input_defaults_file, full_options, true);
+    vector<string> file_unknown= po::collect_unrecognized(file_parsed.options, po::include_positional);
 
-    for (vector<string>::iterator it= file_unknown.begin();
-         it != file_unknown.end();
-         ++it)
+    for (vector<string>::iterator it= file_unknown.begin(); it != file_unknown.end(); ++it)
     {
-      string new_unknown_opt("--");
-      new_unknown_opt.append(*it);
+      string new_unknown_opt("--" + *it);
       ++it;
       if (it == file_unknown.end())
 				break;
-      if ((*it) != "true")
-      {
-        new_unknown_opt.push_back('=');
-        new_unknown_opt.append(*it);
-      }
+      if (*it != "true")
+        new_unknown_opt += "=" + *it;
       unknown_options.push_back(new_unknown_opt);
     }
     store(file_parsed, vm);
   }
 }
 
-static void compose_defaults_file_list(vector<string> in_options)
+static void compose_defaults_file_list(const vector<string>& in_options)
 {
-	BOOST_FOREACH(vector<string>::reference it, in_options)
+	BOOST_FOREACH(const string& it, in_options)
   {
     fs::path p(it);
     if (fs::is_regular_file(p))
@@ -1056,12 +1035,11 @@
 
 int init_basic_variables(int argc, char **argv)
 {
-  time_t curr_time;
   umask(((~internal::my_umask) & 0666));
   decimal_zero.set_zero(); // set decimal_zero constant;
   tzset();			// Set tzname
 
-  curr_time= time(NULL);
+  time_t curr_time= time(NULL);
   if (curr_time == (time_t)-1)
     return 1;
 
@@ -1075,14 +1053,12 @@
   char ret_hostname[FN_REFLEN];
   if (gethostname(ret_hostname,sizeof(ret_hostname)) < 0)
   {
-    errmsg_printf(error::WARN,
-                  _("gethostname failed, using '%s' as hostname"),
-                  getServerHostname().c_str());
+    errmsg_printf(error::WARN, _("gethostname failed, using '%s' as hostname"), getServerHostname().c_str());
     pid_file= "drizzle";
   }
   else
   {
-    setServerHostname(ret_hostname);
+    g_hostname= ret_hostname;
     pid_file= getServerHostname();
   }
   pid_file.replace_extension(".pid");
@@ -1134,7 +1110,7 @@
   ("completion-type", po::value<uint32_t>(&global_system_variables.completion_type)->default_value(0)->notifier(&check_limits_completion_type),
   _("Default completion type."))
   ("core-file",  _("Write core on errors."))
-  ("datadir", po::value<fs::path>(&getDataHome()),
+  ("datadir", po::value<fs::path>(&getMutableDataHome()),
   _("Path to the database root."))
   ("default-storage-engine", po::value<string>(),
   _("Set the default storage engine for tables."))
@@ -1308,28 +1284,19 @@
   {
     fs::path system_config_file_drizzle(system_config_dir);
     system_config_file_drizzle /= "drizzled.cnf";
-    defaults_file_list.insert(defaults_file_list.begin(),
-                              system_config_file_drizzle.file_string());
+    defaults_file_list.insert(defaults_file_list.begin(), system_config_file_drizzle.file_string());
 
     fs::path config_conf_d_location(system_config_dir);
     config_conf_d_location /= "conf.d";
 
-
     CachedDirectory config_conf_d(config_conf_d_location.file_string());
     if (not config_conf_d.fail())
     {
 			BOOST_FOREACH(CachedDirectory::Entries::const_reference iter, config_conf_d.getEntries())
       {
         string file_entry(iter->filename);
-
-        if (not file_entry.empty()
-            && file_entry != "."
-            && file_entry != "..")
-        {
-          fs::path the_entry(config_conf_d_location);
-          the_entry /= file_entry;
-          defaults_file_list.push_back(the_entry.file_string());
-        }
+        if (not file_entry.empty() && file_entry != "." && file_entry != "..")
+          defaults_file_list.push_back((config_conf_d_location / file_entry).file_string());
       }
     }
   }
@@ -1343,10 +1310,7 @@
   }
   catch (po::validation_error &err)
   {
-    errmsg_printf(error::ERROR,
-                  _("%s: %s.\n"
-                    "Use --help to get a list of available options\n"),
-                  internal::my_progname, err.what());
+    errmsg_printf(error::ERROR, _("%s: %s.\nUse --help to get a list of available options\n"), internal::my_progname, err.what());
     unireg_abort(1);
   }
 
@@ -1361,10 +1325,7 @@
   }
   catch (po::validation_error &err)
   {
-    errmsg_printf(error::ERROR,
-                  _("%s: %s.\n"
-                    "Use --help to get a list of available options\n"),
-                  internal::my_progname, err.what());
+    errmsg_printf(error::ERROR, _("%s: %s.\nUse --help to get a list of available options\n"), internal::my_progname, err.what());
     unireg_abort(1);
   }
 
@@ -2064,10 +2025,7 @@
 */
 static void get_options()
 {
-
-  fs::path &data_home_catalog= getDataHomeCatalog();
-  data_home_catalog= getDataHome();
-  data_home_catalog /= "local";
+  setDataHomeCatalog(getDataHome() / "local");
 
   if (vm.count("user"))
   {

=== modified file 'drizzled/field/real.cc'
--- drizzled/field/real.cc	2011-02-19 01:04:19 +0000
+++ drizzled/field/real.cc	2011-06-16 16:39:05 +0000
@@ -29,8 +29,7 @@
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 extern const double log_10[309];
 

=== modified file 'drizzled/main.cc'
--- drizzled/main.cc	2011-05-09 00:03:05 +0000
+++ drizzled/main.cc	2011-06-16 15:27:28 +0000
@@ -323,9 +323,8 @@
       unireg_abort(1);
     }
 
-    boost::filesystem::path &full_data_home= getFullDataHome();
-    full_data_home= boost::filesystem::system_complete(getDataHome());
-    errmsg_printf(error::INFO, "Data Home directory is : %s", full_data_home.native_file_string().c_str());
+    setFullDataHome(boost::filesystem::system_complete(getDataHome()));
+    errmsg_printf(error::INFO, "Data Home directory is : %s", getFullDataHome().native_file_string().c_str());
   }
 
   if (server_id == 0)

=== modified file 'drizzled/session/cache.cc'
--- drizzled/session/cache.cc	2011-04-20 09:12:02 +0000
+++ drizzled/session/cache.cc	2011-06-17 07:07:02 +0000
@@ -19,12 +19,12 @@
 
 #include <config.h>
 #include <drizzled/session/cache.h>
-
-#include <boost/foreach.hpp>
-#include <drizzled/current_session.h>
-#include <drizzled/plugin/authorization.h>
-#include <drizzled/session.h>
-#include <vector>
+
+#include <boost/foreach.hpp>
+#include <drizzled/current_session.h>
+#include <drizzled/plugin/authorization.h>
+#include <drizzled/session.h>
+#include <vector>
 
 namespace drizzled {
 namespace session {

=== modified file 'drizzled/sys_var.h'
--- drizzled/sys_var.h	2011-06-02 15:09:32 +0000
+++ drizzled/sys_var.h	2011-06-16 16:39:05 +0000
@@ -52,13 +52,13 @@
 extern boost::filesystem::path basedir;
 extern boost::filesystem::path pid_file;
 extern boost::filesystem::path secure_file_priv;
-extern char *opt_tc_log_file;
+extern const char *opt_tc_log_file;
 extern uint64_t session_startup_options;
 extern uint32_t global_thread_id;
 extern uint64_t table_cache_size;
 extern back_log_constraints back_log;
 extern uint32_t ha_open_options;
-extern char *drizzled_bind_host;
+extern const char *drizzled_bind_host;
 extern uint32_t dropping_tables;
 extern bool opt_endinfo;
 extern uint32_t volatile thread_running;

=== modified file 'examples/pipe_query.cc'
--- examples/pipe_query.cc	2011-03-29 09:33:49 +0000
+++ examples/pipe_query.cc	2011-06-16 11:54:25 +0000
@@ -34,9 +34,6 @@
  *
  */
 
-
-#include <config.h>
-
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>

=== modified file 'examples/proxy.cc'
--- examples/proxy.cc	2011-03-22 18:39:54 +0000
+++ examples/proxy.cc	2011-06-16 11:54:25 +0000
@@ -34,9 +34,6 @@
  *
  */
 
-
-#include <config.h>
-
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>

=== modified file 'examples/simple.cc'
--- examples/simple.cc	2011-03-22 18:39:54 +0000
+++ examples/simple.cc	2011-06-15 19:07:41 +0000
@@ -34,37 +34,26 @@
  *
  */
 
-
-#include <config.h>
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <netdb.h>
-#include <getopt.h>
-
-#include <libdrizzle/drizzle_client.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <getopt.h>
+#include <libdrizzle/drizzle_client.h>
+#include <netdb.h>
+#include <unistd.h>
 
 int main(int argc, char *argv[])
 {
-  int c;
-  const char *db= "INFORMATION_SCHEMA";
-  const char *host= NULL;
+  const char* db= "information_schema";
+  const char* host= NULL;
   bool mysql= false;
   in_port_t port= 0;
-  const char *query= "SELECT TABLE_SCHEMA,TABLE_NAME FROM TABLES";
+  const char* query= "select table_schema, table_name from tables";
   drizzle_verbose_t verbose= DRIZZLE_VERBOSE_NEVER;
-  drizzle_st drizzle;
-  drizzle_con_st *con= (drizzle_con_st*)malloc(sizeof(drizzle_con_st));
-  drizzle_result_st result;
-  drizzle_return_t ret;
-  int x;
-  char **row;
 
-  while ((c = getopt(argc, argv, "d:h:mp:q:v")) != -1)
+  for (int c; (c = getopt(argc, argv, "d:h:mp:q:v")) != -1; )
   {
-    switch(c)
+    switch (c)
     {
     case 'd':
       db= optarg;
@@ -87,7 +76,7 @@
       break;
 
     case 'v':
-      switch(verbose)
+      switch (verbose)
       {
       case DRIZZLE_VERBOSE_NEVER:
         verbose= DRIZZLE_VERBOSE_FATAL;
@@ -123,6 +112,7 @@
     }
   }
 
+  drizzle_st drizzle;
   if (drizzle_create(&drizzle) == NULL)
   {
     printf("drizzle_create:NULL\n");
@@ -131,6 +121,7 @@
 
   drizzle_set_verbose(&drizzle, verbose);
 
+  drizzle_con_st* con= new drizzle_con_st;
   if (drizzle_con_create(&drizzle, con) == NULL)
   {
     printf("drizzle_con_create:NULL\n");
@@ -143,6 +134,8 @@
   drizzle_con_set_tcp(con, host, port);
   drizzle_con_set_db(con, db);
 
+  drizzle_result_st result;
+  drizzle_return_t ret;
   (void)drizzle_query_str(con, &result, query, &ret);
   if (ret != DRIZZLE_RETURN_OK)
   {
@@ -157,9 +150,9 @@
     return 1;
   }
 
-  while ((row= (char **)drizzle_row_next(&result)) != NULL)
+  while (drizzle_row_t row= drizzle_row_next(&result))
   {
-    for (x= 0; x < drizzle_result_column_count(&result); x++)
+    for (int x= 0; x < drizzle_result_column_count(&result); x++)
       printf("%s%s", x == 0 ? "" : ":", row[x] == NULL ? "NULL" : row[x]);
     printf("\n");
   }
@@ -167,7 +160,6 @@
   drizzle_result_free(&result);
   drizzle_con_free(con);
   drizzle_free(&drizzle);
-
-  free(con);
+  delete con;
   return 0;
 }

=== modified file 'examples/simple_multi.cc'
--- examples/simple_multi.cc	2011-03-22 18:39:54 +0000
+++ examples/simple_multi.cc	2011-06-16 11:54:25 +0000
@@ -34,9 +34,6 @@
  *
  */
 
-
-#include <config.h>
-
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>

=== modified file 'libdrizzle-2.0/libdrizzle/conn.cc'
--- libdrizzle-2.0/libdrizzle/conn.cc	2011-06-14 21:15:09 +0000
+++ libdrizzle-2.0/libdrizzle/conn.cc	2011-06-16 14:41:25 +0000
@@ -70,11 +70,9 @@
 
 drizzle_return_t drizzle_con_set_fd(drizzle_con_st *con, int fd)
 {
-  drizzle_return_t ret;
-
   con->fd= fd;
 
-  ret= _con_setsockopt(con);
+  drizzle_return_t ret= _con_setsockopt(con);
   if (ret != DRIZZLE_RETURN_OK)
     con->drizzle->last_errno= errno;
 
@@ -101,8 +99,6 @@
 
 drizzle_return_t drizzle_con_set_events(drizzle_con_st *con, short events)
 {
-  drizzle_return_t ret;
-
   if ((con->events | events) == con->events)
     return DRIZZLE_RETURN_OK;
 
@@ -110,7 +106,7 @@
 
   if (con->drizzle->event_watch_fn != NULL)
   {
-    ret= con->drizzle->event_watch_fn(con, con->events,
+    drizzle_return_t ret= con->drizzle->event_watch_fn(con, con->events,
                                       con->drizzle->event_watch_context);
     if (ret != DRIZZLE_RETURN_OK)
     {
@@ -124,8 +120,6 @@
 
 drizzle_return_t drizzle_con_set_revents(drizzle_con_st *con, short revents)
 {
-  drizzle_return_t ret;
-
   if (revents != 0)
     con->options|= DRIZZLE_CON_IO_READY;
 
@@ -138,7 +132,7 @@
   if (revents & POLLOUT && !(con->events & POLLOUT) &&
       con->drizzle->event_watch_fn != NULL)
   {
-    ret= con->drizzle->event_watch_fn(con, con->events,
+    drizzle_return_t ret= con->drizzle->event_watch_fn(con, con->events,
                                       con->drizzle->event_watch_context);
     if (ret != DRIZZLE_RETURN_OK)
     {
@@ -328,10 +322,9 @@
   uint32_t major;
   uint32_t minor;
   uint32_t version;
-  const char *current;
   char *end;
 
-  current= con->server_version;
+  const char *current= con->server_version;
 
   major= (uint32_t)strtoul(current, &end, 10);
   current= end + 1;
@@ -788,6 +781,7 @@
       snprintf(port, NI_MAXSERV, "%u", DRIZZLE_DEFAULT_TCP_PORT);
     port[NI_MAXSERV-1]= 0;
 
+    memset(&ai, 0, sizeof(ai));
     ai.ai_socktype= SOCK_STREAM;
     ai.ai_protocol= IPPROTO_TCP;
     ai.ai_flags = AI_PASSIVE;
@@ -820,9 +814,6 @@
   case DRIZZLE_CON_SOCKET_UDS:
     con->addrinfo_next= &(con->socket.uds.addrinfo);
     break;
-
-  default:
-    break;
   }
 
   drizzle_state_pop(con);
@@ -831,9 +822,6 @@
 
 drizzle_return_t drizzle_state_connect(drizzle_con_st *con)
 {
-  int ret;
-  drizzle_return_t dret;
-
   drizzle_log_debug(con->drizzle, "drizzle_state_connect");
 
   if (con->fd != -1)
@@ -861,7 +849,7 @@
     return DRIZZLE_RETURN_ERRNO;
   }
 
-  dret= _con_setsockopt(con);
+  drizzle_return_t dret= _con_setsockopt(con);
   if (dret != DRIZZLE_RETURN_OK)
   {
     con->drizzle->last_errno= errno;
@@ -870,8 +858,7 @@
 
   while (1)
   {
-    ret= connect(con->fd, con->addrinfo_next->ai_addr,
-                 con->addrinfo_next->ai_addrlen);
+    int ret= connect(con->fd, con->addrinfo_next->ai_addr, con->addrinfo_next->ai_addrlen);
 
 #ifdef _WIN32
     errno = WSAGetLastError();
@@ -943,8 +930,6 @@
 
 drizzle_return_t drizzle_state_connecting(drizzle_con_st *con)
 {
-  drizzle_return_t ret;
-
   drizzle_log_debug(con->drizzle, "drizzle_state_connecting");
 
   while (1)
@@ -963,7 +948,7 @@
       return DRIZZLE_RETURN_OK;
     }
 
-    ret= drizzle_con_set_events(con, POLLOUT);
+    drizzle_return_t ret= drizzle_con_set_events(con, POLLOUT);
     if (ret != DRIZZLE_RETURN_OK)
       return ret;
 
@@ -979,7 +964,6 @@
 drizzle_return_t drizzle_state_read(drizzle_con_st *con)
 {
   drizzle_return_t ret;
-  ssize_t read_size;
 
   drizzle_log_debug(con->drizzle, "drizzle_state_read");
 
@@ -1007,7 +991,7 @@
   {
     size_t available_buffer= (size_t)DRIZZLE_MAX_BUFFER_SIZE -
         ((size_t)(con->buffer_ptr - con->buffer) + con->buffer_size);
-    read_size = recv(con->fd, (char *)con->buffer_ptr + con->buffer_size,
+    ssize_t read_size = recv(con->fd, (char *)con->buffer_ptr + con->buffer_size,
                      available_buffer, 0);
 #ifdef _WIN32
     errno = WSAGetLastError();
@@ -1109,14 +1093,12 @@
 drizzle_return_t drizzle_state_write(drizzle_con_st *con)
 {
   drizzle_return_t ret;
-  ssize_t write_size;
 
   drizzle_log_debug(con->drizzle, "drizzle_state_write");
 
   while (con->buffer_size != 0)
   {
-  
-    write_size = send(con->fd,(char *) con->buffer_ptr, con->buffer_size, 0);
+    ssize_t write_size = send(con->fd,(char *) con->buffer_ptr, con->buffer_size, 0);
 
 #ifdef _WIN32
     errno = WSAGetLastError();

=== modified file 'libdrizzle-2.0/libdrizzle/drizzle.cc'
--- libdrizzle-2.0/libdrizzle/drizzle.cc	2011-06-14 21:15:09 +0000
+++ libdrizzle-2.0/libdrizzle/drizzle.cc	2011-06-16 14:52:39 +0000
@@ -66,12 +66,12 @@
  * Common Definitions
  */
 
-const char *drizzle_version(void)
+const char *drizzle_version()
 {
   return PACKAGE_VERSION;
 }
 
-const char *drizzle_bugreport(void)
+const char *drizzle_bugreport()
 {
   return PACKAGE_BUGREPORT;
 }
@@ -136,15 +136,13 @@
 
 drizzle_st *drizzle_clone(drizzle_st *drizzle, const drizzle_st *from)
 {
-  drizzle_con_st *con;
-
   drizzle= drizzle_create(drizzle);
   if (drizzle == NULL)
     return NULL;
 
   drizzle->options|= (from->options & ~DRIZZLE_ALLOCATED);
 
-  for (con= from->con_list; con != NULL; con= con->next)
+  for (drizzle_con_st* con= from->con_list; con != NULL; con= con->next)
   {
     if (drizzle_con_clone(drizzle, NULL, con) == NULL)
     {
@@ -169,7 +167,7 @@
   else if (drizzle->options & DRIZZLE_ASSERT_DANGLING)
   {
     assert(drizzle->con_list == NULL);
-    assert(drizzle->con_list == NULL);
+    assert(drizzle->query_list == NULL);
   }
 
   if (drizzle->pfds != NULL)
@@ -185,7 +183,7 @@
 
 const char *drizzle_error(const drizzle_st *drizzle)
 {
-  return (const char *)drizzle->last_error;
+  return drizzle->last_error;
 }
 
 int drizzle_errno(const drizzle_st *drizzle)
@@ -364,9 +362,6 @@
   case DRIZZLE_CON_SOCKET_UDS:
     drizzle_con_set_uds(con, from->socket.uds.sockaddr.sun_path);
     break;
-
-  default:
-    break;
   }
 
   return con;
@@ -407,9 +402,7 @@
 
 drizzle_return_t drizzle_con_wait(drizzle_st *drizzle)
 {
-  drizzle_con_st *con;
   struct pollfd *pfds;
-  uint32_t x;
   int ret;
   drizzle_return_t dret;
 
@@ -428,8 +421,8 @@
   else
     pfds= drizzle->pfds;
 
-  x= 0;
-  for (con= drizzle->con_list; con != NULL; con= con->next)
+  uint32_t x= 0;
+  for (drizzle_con_st* con= drizzle->con_list; con != NULL; con= con->next)
   {
     if (con->events == 0)
       continue;
@@ -476,7 +469,7 @@
   }
 
   x= 0;
-  for (con= drizzle->con_list; con != NULL; con= con->next)
+  for (drizzle_con_st* con= drizzle->con_list; con != NULL; con= con->next)
   {
     if (con->events == 0)
       continue;
@@ -493,12 +486,10 @@
 
 drizzle_con_st *drizzle_con_ready(drizzle_st *drizzle)
 {
-  drizzle_con_st *con;
-
   /* We can't keep state between calls since connections may be removed during
      processing. If this list ever gets big, we may want something faster. */
 
-  for (con= drizzle->con_list; con != NULL; con= con->next)
+  for (drizzle_con_st* con= drizzle->con_list; con != NULL; con= con->next)
   {
     if (con->options & DRIZZLE_CON_IO_READY)
     {
@@ -506,18 +497,15 @@
       return con;
     }
   }
-
   return NULL;
 }
 
 drizzle_con_st *drizzle_con_ready_listen(drizzle_st *drizzle)
 {
-  drizzle_con_st *con;
-
   /* We can't keep state between calls since connections may be removed during
      processing. If this list ever gets big, we may want something faster. */
 
-  for (con= drizzle->con_list; con != NULL; con= con->next)
+  for (drizzle_con_st* con= drizzle->con_list; con != NULL; con= con->next)
   {
     if ((con->options & (DRIZZLE_CON_IO_READY | DRIZZLE_CON_LISTEN)) ==
         (DRIZZLE_CON_IO_READY | DRIZZLE_CON_LISTEN))
@@ -526,7 +514,6 @@
       return con;
     }
   }
-
   return NULL;
 }
 
@@ -609,14 +596,11 @@
 drizzle_con_st *drizzle_con_accept(drizzle_st *drizzle, drizzle_con_st *con,
                                    drizzle_return_t *ret_ptr)
 {
-  drizzle_con_st *ready;
-  int fd;
-
   while (1)
   {
-    if ((ready= drizzle_con_ready_listen(drizzle)) != NULL)
+    if (drizzle_con_st* ready= drizzle_con_ready_listen(drizzle))
     {
-      fd= accept(ready->fd, NULL, NULL);
+      int fd= accept(ready->fd, NULL, NULL);
 
       con= drizzle_con_create(drizzle, con);
       if (con == NULL)
@@ -646,7 +630,7 @@
       return NULL;
     }
 
-    for (ready= drizzle->con_list; ready != NULL; ready= ready->next)
+    for (drizzle_con_st* ready= drizzle->con_list; ready != NULL; ready= ready->next)
     {
       if (ready->options & DRIZZLE_CON_LISTEN)
         drizzle_con_set_events(ready, POLLIN);
@@ -665,21 +649,18 @@
 void drizzle_set_error(drizzle_st *drizzle, const char *function,
                        const char *format, ...)
 {
-  size_t size;
-  int written;
-  char *ptr;
   char log_buffer[DRIZZLE_MAX_ERROR_SIZE];
-  va_list args;
 
-  size= strlen(function);
-  ptr= (char *)memcpy(log_buffer, function, size);
+  size_t size= strlen(function);
+  char* ptr= (char *)memcpy(log_buffer, function, size);
   ptr+= size;
   ptr[0]= ':';
   size++;
   ptr++;
 
+  va_list args;
   va_start(args, format);
-  written= vsnprintf(ptr, DRIZZLE_MAX_ERROR_SIZE - size, format, args);
+  int written= vsnprintf(ptr, DRIZZLE_MAX_ERROR_SIZE - size, format, args);
   va_end(args);
 
   if (written < 0) size= DRIZZLE_MAX_ERROR_SIZE;

=== modified file 'libdrizzle-2.0/libdrizzle/libdrizzle.h'
--- libdrizzle-2.0/libdrizzle/libdrizzle.h	2011-03-22 18:39:54 +0000
+++ libdrizzle-2.0/libdrizzle/libdrizzle.h	2011-06-15 22:34:12 +0000
@@ -1,18 +1,34 @@
-/* Drizzle
+/* Drizzle Client Library
  * Copyright (C) 2011 Olaf van der Spek
- * 
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 2 of the License, or
- * (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *     * Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ *
+ *     * Redistributions in binary form must reproduce the above
+ * copyright notice, this list of conditions and the following disclaimer
+ * in the documentation and/or other materials provided with the
+ * distribution.
+ *
+ *     * The names of its contributors may not be used to endorse or
+ * promote products derived from this software without specific prior
+ * written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #pragma once

=== modified file 'libdrizzle-2.0/libdrizzle/libdrizzle.hpp'
--- libdrizzle-2.0/libdrizzle/libdrizzle.hpp	2011-06-16 15:05:43 +0000
+++ libdrizzle-2.0/libdrizzle/libdrizzle.hpp	2011-06-17 07:07:02 +0000
@@ -31,6 +31,154 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#pragma once
-
-#include <libdrizzle/libdrizzle.h>
+#pragma once
+
+#include <cstring>
+#include <libdrizzle/libdrizzle.h>
+#include <stdexcept>
+
+namespace drizzle {
+
+class bad_query : public std::runtime_error
+{
+};
+
+class drizzle_c
+{
+public:
+  drizzle_c()
+  {
+    drizzle_create(&b_);
+  }
+
+  ~drizzle_c()
+  {
+    drizzle_free(&b_);
+  }
+
+  drizzle_st b_;
+};
+
+class result_c
+{
+public:
+  result_c()
+  {
+    memset(&b_, 0, sizeof(b_));
+  }
+
+  ~result_c()
+  {
+    drizzle_result_free(&b_);
+  }
+
+  const char* error()
+  {
+    return drizzle_result_error(&b_);
+  }
+
+  uint16_t error_code()
+  {
+    return drizzle_result_error_code(&b_);
+  }
+
+  uint16_t column_count()
+  {
+    return drizzle_result_column_count(&b_);    
+  }
+
+  uint64_t row_count()
+  {
+    return drizzle_result_row_count(&b_);
+  }
+
+  drizzle_column_st* column_next()
+  {
+    return drizzle_column_next(&b_);
+  }
+
+  drizzle_row_t row_next()
+  {
+    return drizzle_row_next(&b_);
+  }
+
+  void column_seek(uint16_t i)
+  {
+    drizzle_column_seek(&b_, i);
+  }
+
+  void row_seek(uint64_t i)
+  {
+    drizzle_row_seek(&b_, i);
+  }
+
+  size_t* row_field_sizes()
+  {
+    return drizzle_row_field_sizes(&b_);
+  }
+
+  drizzle_result_st b_;
+};
+
+class connection_c
+{
+public:
+  explicit connection_c(drizzle_c& drizzle)
+  {
+    drizzle_con_create(&drizzle.b_, &b_);
+  }
+
+  ~connection_c()
+  {
+    drizzle_con_free(&b_);
+  }
+
+  const char* error()
+  {
+    return drizzle_con_error(&b_);
+  }
+
+  drizzle_return_t query(result_c& result, const char* str, size_t str_size)
+  {
+    drizzle_return_t ret;
+    drizzle_query(&b_, &result.b_, str, str_size, &ret);
+    if (ret == DRIZZLE_RETURN_OK)
+      ret = drizzle_result_buffer(&result.b_);
+    return ret;
+  }
+
+  drizzle_return_t query(result_c& result, const std::string& str)
+  {
+    return query(result, str.data(), str.size());
+  }
+
+  drizzle_return_t query(result_c& result, const char* str)
+  {
+    return query(result, str, strlen(str));
+  }
+
+  drizzle_con_st b_;
+};
+
+/*
+inline drizzle_return_t query(drizzle_con_st* con, result_c& result, const char* str, size_t str_size)
+{
+  drizzle_return_t ret;
+  drizzle_query(con, &result.b_, str, str_size, &ret);
+  if (ret == DRIZZLE_RETURN_OK)
+    ret = drizzle_result_buffer(&result.b_);
+  return ret;
+}
+
+inline drizzle_return_t query(drizzle_con_st* con, result_c& result, const std::string& str)
+{
+  return query(con, result, str.data(), str.size());
+}
+
+inline drizzle_return_t query(drizzle_con_st* con, result_c& result, const char* str)
+{
+  return query(con, result, str, strlen(str));
+}
+*/
+
+}

=== modified file 'win32/drizzle.sln'
--- win32/drizzle.sln	2011-04-03 18:32:46 +0000
+++ win32/drizzle.sln	2011-06-17 07:07:02 +0000
@@ -1,26 +1,26 @@
-﻿
-Microsoft Visual Studio Solution File, Format Version 11.00
-# Visual Studio 2010
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-2.0", "libdrizzle-2.0.vcxproj", "{786CDCC5-9B40-4927-B8B3-DC484E138EE9}"
-EndProject
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-1.0", "libdrizzle-1.0.vcxproj", "{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}"
-EndProject
-Global
-	GlobalSection(SolutionConfigurationPlatforms) = preSolution
-		Debug|Win32 = Debug|Win32
-		Release|Win32 = Release|Win32
-	EndGlobalSection
-	GlobalSection(ProjectConfigurationPlatforms) = postSolution
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.ActiveCfg = Debug|Win32
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.Build.0 = Debug|Win32
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.ActiveCfg = Release|Win32
-		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.Build.0 = Release|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.ActiveCfg = Debug|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.Build.0 = Debug|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.ActiveCfg = Release|Win32
-		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.Build.0 = Release|Win32
-	EndGlobalSection
-	GlobalSection(SolutionProperties) = preSolution
-		HideSolutionNode = FALSE
-	EndGlobalSection
-EndGlobal
+﻿
+Microsoft Visual Studio Solution File, Format Version 11.00
+# Visual Studio 2010
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-2.0", "libdrizzle-2.0.vcxproj", "{786CDCC5-9B40-4927-B8B3-DC484E138EE9}"
+EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "libdrizzle-1.0", "libdrizzle-1.0.vcxproj", "{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}"
+EndProject
+Global
+	GlobalSection(SolutionConfigurationPlatforms) = preSolution
+		Debug|Win32 = Debug|Win32
+		Release|Win32 = Release|Win32
+	EndGlobalSection
+	GlobalSection(ProjectConfigurationPlatforms) = postSolution
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.ActiveCfg = Debug|Win32
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Debug|Win32.Build.0 = Debug|Win32
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.ActiveCfg = Release|Win32
+		{786CDCC5-9B40-4927-B8B3-DC484E138EE9}.Release|Win32.Build.0 = Release|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.ActiveCfg = Debug|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Debug|Win32.Build.0 = Debug|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.ActiveCfg = Release|Win32
+		{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}.Release|Win32.Build.0 = Release|Win32
+	EndGlobalSection
+	GlobalSection(SolutionProperties) = preSolution
+		HideSolutionNode = FALSE
+	EndGlobalSection
+EndGlobal

=== modified file 'win32/libdrizzle-1.0.vcxproj'
--- win32/libdrizzle-1.0.vcxproj	2011-04-03 18:32:46 +0000
+++ win32/libdrizzle-1.0.vcxproj	2011-06-17 07:07:02 +0000
@@ -1,144 +1,144 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup Label="ProjectConfigurations">
-    <ProjectConfiguration Include="Debug|Win32">
-      <Configuration>Debug</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|Win32">
-      <Configuration>Release</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-  </ItemGroup>
-  <PropertyGroup Label="Globals">
-    <ProjectGuid>{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}</ProjectGuid>
-    <RootNamespace>libdrizzle10</RootNamespace>
-    <Keyword>Win32Proj</Keyword>
-    <ProjectName>libdrizzle-1.0</ProjectName>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
-  <ImportGroup Label="ExtensionSettings">
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <PropertyGroup Label="UserMacros" />
-  <PropertyGroup>
-    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-  </PropertyGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-1.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
-      <CompileAs>CompileAsC</CompileAs>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <ClCompile>
-      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-1.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <OptimizeReferences>true</OptimizeReferences>
-      <EnableCOMDATFolding>true</EnableCOMDATFolding>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemGroup>
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\common.h" />
-    <ClInclude Include="config.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_local.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\constants.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_local.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_server.h" />
-    <ClInclude Include="windows\inttypes.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\pack.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\query.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_client.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_server.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\sha1.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\state.h" />
-    <ClInclude Include="windows\stdint.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\structs.h" />
-    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\visibility.h" />
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\column.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\command.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\conn.c" />
-    <ClCompile Include="conn_uds.cc" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\drizzle.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\field.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\handshake.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\pack.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\query.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\result.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\row.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\sha1.c" />
-    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\state.c" />
-  </ItemGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
-  <ImportGroup Label="ExtensionTargets">
-  </ImportGroup>
-</Project>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>{EDFED9AB-462B-4BB6-99B0-D507C1B585A0}</ProjectGuid>
+    <RootNamespace>libdrizzle10</RootNamespace>
+    <Keyword>Win32Proj</Keyword>
+    <ProjectName>libdrizzle-1.0</ProjectName>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup>
+    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+  </PropertyGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-1.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
+      <CompileAs>CompileAsC</CompileAs>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <ClCompile>
+      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-1.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <OptimizeReferences>true</OptimizeReferences>
+      <EnableCOMDATFolding>true</EnableCOMDATFolding>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\column_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\command_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\common.h" />
+    <ClInclude Include="config.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_local.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\conn_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\constants.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_local.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\drizzle_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\field_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\handshake_server.h" />
+    <ClInclude Include="windows\inttypes.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\pack.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\query.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\result_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_client.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\row_server.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\sha1.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\state.h" />
+    <ClInclude Include="windows\stdint.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\structs.h" />
+    <ClInclude Include="..\libdrizzle-1.0\libdrizzle\visibility.h" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\column.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\command.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\conn.c" />
+    <ClCompile Include="conn_uds.cc" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\drizzle.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\field.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\handshake.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\pack.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\query.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\result.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\row.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\sha1.c" />
+    <ClCompile Include="..\libdrizzle-1.0\libdrizzle\state.c" />
+  </ItemGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
+  <ImportGroup Label="ExtensionTargets">
+  </ImportGroup>
+</Project>

=== modified file 'win32/libdrizzle-1.0.vcxproj.filters'
--- win32/libdrizzle-1.0.vcxproj.filters	2011-04-03 18:32:46 +0000
+++ win32/libdrizzle-1.0.vcxproj.filters	2011-06-17 07:07:02 +0000
@@ -1,17 +1,17 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup>
-    <Filter Include="Source Files">
-      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
-      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
-    </Filter>
-    <Filter Include="Header Files">
-      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
-      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
-    </Filter>
-    <Filter Include="Resource Files">
-      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
-      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx;tiff;tif;png;wav;mfcribbon-ms</Extensions>
-    </Filter>
-  </ItemGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup>
+    <Filter Include="Source Files">
+      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
+      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
+    </Filter>
+    <Filter Include="Header Files">
+      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
+      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
+    </Filter>
+    <Filter Include="Resource Files">
+      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
+      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx;tiff;tif;png;wav;mfcribbon-ms</Extensions>
+    </Filter>
+  </ItemGroup>
 </Project>
\ No newline at end of file

=== modified file 'win32/libdrizzle-2.0.vcxproj'
--- win32/libdrizzle-2.0.vcxproj	2011-04-03 19:25:54 +0000
+++ win32/libdrizzle-2.0.vcxproj	2011-06-17 07:07:02 +0000
@@ -1,143 +1,143 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup Label="ProjectConfigurations">
-    <ProjectConfiguration Include="Debug|Win32">
-      <Configuration>Debug</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|Win32">
-      <Configuration>Release</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-  </ItemGroup>
-  <PropertyGroup Label="Globals">
-    <ProjectGuid>{786CDCC5-9B40-4927-B8B3-DC484E138EE9}</ProjectGuid>
-    <RootNamespace>libdrizzle</RootNamespace>
-    <Keyword>Win32Proj</Keyword>
-    <ProjectName>libdrizzle-2.0</ProjectName>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
-  <ImportGroup Label="ExtensionSettings">
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <PropertyGroup Label="UserMacros" />
-  <PropertyGroup>
-    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
-    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
-    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
-  </PropertyGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-2.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <ClCompile>
-      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-2.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
-    </ClCompile>
-    <Link>
-      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <OptimizeReferences>true</OptimizeReferences>
-      <EnableCOMDATFolding>true</EnableCOMDATFolding>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemGroup>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h" />
-    <ClInclude Include="config.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h" />
-    <ClInclude Include="windows\inttypes.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h" />
-    <ClInclude Include="windows\stdint.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h" />
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h" />
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc" />
-    <ClCompile Include="conn_uds.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc" />
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc" />
-  </ItemGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
-  <ImportGroup Label="ExtensionTargets">
-  </ImportGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>{786CDCC5-9B40-4927-B8B3-DC484E138EE9}</ProjectGuid>
+    <RootNamespace>libdrizzle</RootNamespace>
+    <Keyword>Win32Proj</Keyword>
+    <ProjectName>libdrizzle-2.0</ProjectName>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
+    <ConfigurationType>DynamicLibrary</ConfigurationType>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup>
+    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Debug\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Release\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" />
+    <CodeAnalysisRuleSet Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">AllRules.ruleset</CodeAnalysisRuleSet>
+    <CodeAnalysisRules Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+    <CodeAnalysisRuleAssemblies Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" />
+  </PropertyGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(ProjectDir)\windows;$(ProjectDir);$(ProjectDir)\..\libdrizzle-2.0;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <ClCompile>
+      <AdditionalIncludeDirectories>$(ProjectDir)\..\libdrizzle-2.0;$(ProjectDir)\windows;$(ProjectDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;_USRDLL;LIBDRIZZLE_EXPORTS;_CRT_SECURE_NO_WARNINGS;__STDC_LIMIT_MACROS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
+    </ClCompile>
+    <Link>
+      <AdditionalDependencies>wsock32.lib;Ws2_32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <SubSystem>Windows</SubSystem>
+      <OptimizeReferences>true</OptimizeReferences>
+      <EnableCOMDATFolding>true</EnableCOMDATFolding>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h" />
+    <ClInclude Include="config.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h" />
+    <ClInclude Include="windows\inttypes.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h" />
+    <ClInclude Include="windows\stdint.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h" />
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc" />
+    <ClCompile Include="conn_uds.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc" />
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc" />
+  </ItemGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
+  <ImportGroup Label="ExtensionTargets">
+  </ImportGroup>
 </Project>
\ No newline at end of file

=== modified file 'win32/libdrizzle-2.0.vcxproj.filters'
--- win32/libdrizzle-2.0.vcxproj.filters	2011-04-03 18:14:47 +0000
+++ win32/libdrizzle-2.0.vcxproj.filters	2011-06-17 07:07:02 +0000
@@ -1,159 +1,159 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup>
-    <Filter Include="Header Files">
-      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
-      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
-    </Filter>
-    <Filter Include="Resource Files">
-      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
-      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx</Extensions>
-    </Filter>
-    <Filter Include="Source Files">
-      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
-      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
-    </Filter>
-  </ItemGroup>
-  <ItemGroup>
-    <ClInclude Include="config.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="windows\inttypes.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="windows\stdint.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="conn_uds.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-  </ItemGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup>
+    <Filter Include="Header Files">
+      <UniqueIdentifier>{93995380-89BD-4b04-88EB-625FBE52EBFB}</UniqueIdentifier>
+      <Extensions>h;hpp;hxx;hm;inl;inc;xsd</Extensions>
+    </Filter>
+    <Filter Include="Resource Files">
+      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
+      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx</Extensions>
+    </Filter>
+    <Filter Include="Source Files">
+      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
+      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
+    </Filter>
+  </ItemGroup>
+  <ItemGroup>
+    <ClInclude Include="config.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="windows\inttypes.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="windows\stdint.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\column_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\command_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\common.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_local.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\conn_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\constants.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_local.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\drizzle_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\field_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\handshake_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\pack.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\query.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\result_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_client.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\row_server.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\sha1.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\state.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\structs.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+    <ClInclude Include="..\libdrizzle-2.0\libdrizzle\visibility.h">
+      <Filter>Header Files</Filter>
+    </ClInclude>
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\column.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\command.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\conn.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="conn_uds.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\drizzle.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\field.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\handshake.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\pack.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\query.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\result.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\row.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\sha1.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+    <ClCompile Include="..\libdrizzle-2.0\libdrizzle\state.cc">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+  </ItemGroup>
 </Project>
\ No newline at end of file

